"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.capability.v1beta1.capability_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisOwners(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INDEX_FIELD_NUMBER: builtins.int
    INDEX_OWNERS_FIELD_NUMBER: builtins.int
    index: builtins.int = ...

    @property
    def index_owners(self) -> cosmos.capability.v1beta1.capability_pb2.CapabilityOwners: ...

    def __init__(self,
        *,
        index : builtins.int = ...,
        index_owners : typing.Optional[cosmos.capability.v1beta1.capability_pb2.CapabilityOwners] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"index_owners",b"index_owners"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"index",b"index",u"index_owners",b"index_owners"]) -> None: ...
global___GenesisOwners = GenesisOwners

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INDEX_FIELD_NUMBER: builtins.int
    OWNERS_FIELD_NUMBER: builtins.int
    index: builtins.int = ...

    @property
    def owners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GenesisOwners]: ...

    def __init__(self,
        *,
        index : builtins.int = ...,
        owners : typing.Optional[typing.Iterable[global___GenesisOwners]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"index",b"index",u"owners",b"owners"]) -> None: ...
global___GenesisState = GenesisState
