"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConsensusParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BLOCK_FIELD_NUMBER: builtins.int
    EVIDENCE_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int

    @property
    def block(self) -> global___BlockParams: ...

    @property
    def evidence(self) -> global___EvidenceParams: ...

    @property
    def validator(self) -> global___ValidatorParams: ...

    @property
    def version(self) -> global___VersionParams: ...

    def __init__(self,
        *,
        block : typing.Optional[global___BlockParams] = ...,
        evidence : typing.Optional[global___EvidenceParams] = ...,
        validator : typing.Optional[global___ValidatorParams] = ...,
        version : typing.Optional[global___VersionParams] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"block",b"block",u"evidence",b"evidence",u"validator",b"validator",u"version",b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block",b"block",u"evidence",b"evidence",u"validator",b"validator",u"version",b"version"]) -> None: ...
global___ConsensusParams = ConsensusParams

class BlockParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MAX_BYTES_FIELD_NUMBER: builtins.int
    MAX_GAS_FIELD_NUMBER: builtins.int
    TIME_IOTA_MS_FIELD_NUMBER: builtins.int
    max_bytes: builtins.int = ...
    max_gas: builtins.int = ...
    time_iota_ms: builtins.int = ...

    def __init__(self,
        *,
        max_bytes : builtins.int = ...,
        max_gas : builtins.int = ...,
        time_iota_ms : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"max_bytes",b"max_bytes",u"max_gas",b"max_gas",u"time_iota_ms",b"time_iota_ms"]) -> None: ...
global___BlockParams = BlockParams

class EvidenceParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MAX_AGE_NUM_BLOCKS_FIELD_NUMBER: builtins.int
    MAX_AGE_DURATION_FIELD_NUMBER: builtins.int
    MAX_BYTES_FIELD_NUMBER: builtins.int
    max_age_num_blocks: builtins.int = ...
    max_bytes: builtins.int = ...

    @property
    def max_age_duration(self) -> google.protobuf.duration_pb2.Duration: ...

    def __init__(self,
        *,
        max_age_num_blocks : builtins.int = ...,
        max_age_duration : typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        max_bytes : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"max_age_duration",b"max_age_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"max_age_duration",b"max_age_duration",u"max_age_num_blocks",b"max_age_num_blocks",u"max_bytes",b"max_bytes"]) -> None: ...
global___EvidenceParams = EvidenceParams

class ValidatorParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PUB_KEY_TYPES_FIELD_NUMBER: builtins.int

    @property
    def pub_key_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        pub_key_types : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pub_key_types",b"pub_key_types"]) -> None: ...
global___ValidatorParams = ValidatorParams

class VersionParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    APP_VERSION_FIELD_NUMBER: builtins.int
    app_version: builtins.int = ...

    def __init__(self,
        *,
        app_version : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"app_version",b"app_version"]) -> None: ...
global___VersionParams = VersionParams

class HashedParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BLOCK_MAX_BYTES_FIELD_NUMBER: builtins.int
    BLOCK_MAX_GAS_FIELD_NUMBER: builtins.int
    block_max_bytes: builtins.int = ...
    block_max_gas: builtins.int = ...

    def __init__(self,
        *,
        block_max_bytes : builtins.int = ...,
        block_max_gas : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block_max_bytes",b"block_max_bytes",u"block_max_gas",b"block_max_gas"]) -> None: ...
global___HashedParams = HashedParams
