"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FungibleTokenPacketData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DENOM_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    RECEIVER_FIELD_NUMBER: builtins.int
    denom: typing.Text = ...
    amount: builtins.int = ...
    sender: typing.Text = ...
    receiver: typing.Text = ...

    def __init__(self,
        *,
        denom : typing.Text = ...,
        amount : builtins.int = ...,
        sender : typing.Text = ...,
        receiver : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"denom",b"denom",u"receiver",b"receiver",u"sender",b"sender"]) -> None: ...
global___FungibleTokenPacketData = FungibleTokenPacketData

class DenomTrace(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PATH_FIELD_NUMBER: builtins.int
    BASE_DENOM_FIELD_NUMBER: builtins.int
    path: typing.Text = ...
    base_denom: typing.Text = ...

    def __init__(self,
        *,
        path : typing.Text = ...,
        base_denom : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"base_denom",b"base_denom",u"path",b"path"]) -> None: ...
global___DenomTrace = DenomTrace

class Params(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEND_ENABLED_FIELD_NUMBER: builtins.int
    RECEIVE_ENABLED_FIELD_NUMBER: builtins.int
    send_enabled: builtins.bool = ...
    receive_enabled: builtins.bool = ...

    def __init__(self,
        *,
        send_enabled : builtins.bool = ...,
        receive_enabled : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"receive_enabled",b"receive_enabled",u"send_enabled",b"send_enabled"]) -> None: ...
global___Params = Params
