"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MsgCreateClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_STATE_FIELD_NUMBER: builtins.int
    CONSENSUS_STATE_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    signer: typing.Text = ...

    @property
    def client_state(self) -> google.protobuf.any_pb2.Any: ...

    @property
    def consensus_state(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        client_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        consensus_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"client_state",b"client_state",u"consensus_state",b"consensus_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_state",b"client_state",u"consensus_state",b"consensus_state",u"signer",b"signer"]) -> None: ...
global___MsgCreateClient = MsgCreateClient

class MsgCreateClientResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgCreateClientResponse = MsgCreateClientResponse

class MsgUpdateClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    HEADER_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    signer: typing.Text = ...

    @property
    def header(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        header : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"header",b"header",u"signer",b"signer"]) -> None: ...
global___MsgUpdateClient = MsgUpdateClient

class MsgUpdateClientResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgUpdateClientResponse = MsgUpdateClientResponse

class MsgUpgradeClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_STATE_FIELD_NUMBER: builtins.int
    CONSENSUS_STATE_FIELD_NUMBER: builtins.int
    PROOF_UPGRADE_CLIENT_FIELD_NUMBER: builtins.int
    PROOF_UPGRADE_CONSENSUS_STATE_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    proof_upgrade_client: builtins.bytes = ...
    proof_upgrade_consensus_state: builtins.bytes = ...
    signer: typing.Text = ...

    @property
    def client_state(self) -> google.protobuf.any_pb2.Any: ...

    @property
    def consensus_state(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        client_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        consensus_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        proof_upgrade_client : builtins.bytes = ...,
        proof_upgrade_consensus_state : builtins.bytes = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"client_state",b"client_state",u"consensus_state",b"consensus_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"client_state",b"client_state",u"consensus_state",b"consensus_state",u"proof_upgrade_client",b"proof_upgrade_client",u"proof_upgrade_consensus_state",b"proof_upgrade_consensus_state",u"signer",b"signer"]) -> None: ...
global___MsgUpgradeClient = MsgUpgradeClient

class MsgUpgradeClientResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgUpgradeClientResponse = MsgUpgradeClientResponse

class MsgSubmitMisbehaviour(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    MISBEHAVIOUR_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    signer: typing.Text = ...

    @property
    def misbehaviour(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        misbehaviour : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"misbehaviour",b"misbehaviour"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"misbehaviour",b"misbehaviour",u"signer",b"signer"]) -> None: ...
global___MsgSubmitMisbehaviour = MsgSubmitMisbehaviour

class MsgSubmitMisbehaviourResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgSubmitMisbehaviourResponse = MsgSubmitMisbehaviourResponse
