"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.params.v1beta1.params_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SUBSPACE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    subspace: typing.Text = ...
    key: typing.Text = ...

    def __init__(self,
        *,
        subspace : typing.Text = ...,
        key : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"subspace",b"subspace"]) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAM_FIELD_NUMBER: builtins.int

    @property
    def param(self) -> cosmos.params.v1beta1.params_pb2.ParamChange: ...

    def __init__(self,
        *,
        param : typing.Optional[cosmos.params.v1beta1.params_pb2.ParamChange] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"param",b"param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"param",b"param"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse
