# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oracle/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from oracle.v1 import oracle_pb2 as oracle_dot_v1_dot_oracle__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='oracle/v1/query.proto',
  package='oracle.v1',
  syntax='proto3',
  serialized_options=b'Z,github.com/bandprotocol/chain/x/oracle/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15oracle/v1/query.proto\x12\toracle.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x16oracle/v1/oracle.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x14\n\x12QueryCountsRequest\"d\n\x13QueryCountsResponse\x12\x19\n\x11\x64\x61ta_source_count\x18\x01 \x01(\x03\x12\x1b\n\x13oracle_script_count\x18\x02 \x01(\x03\x12\x15\n\rrequest_count\x18\x03 \x01(\x03\"%\n\x10QueryDataRequest\x12\x11\n\tdata_hash\x18\x01 \x01(\t\"!\n\x11QueryDataResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"0\n\x16QueryDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\x03\"E\n\x17QueryDataSourceResponse\x12*\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32\x15.oracle.v1.DataSource\"4\n\x18QueryOracleScriptRequest\x12\x18\n\x10oracle_script_id\x18\x01 \x01(\x03\"K\n\x19QueryOracleScriptResponse\x12.\n\roracle_script\x18\x01 \x01(\x0b\x32\x17.oracle.v1.OracleScript\")\n\x13QueryRequestRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\x03\"\x88\x01\n\x14QueryRequestResponse\x12#\n\x07request\x18\x01 \x01(\x0b\x32\x12.oracle.v1.Request\x12(\n\x07reports\x18\x02 \x03(\x0b\x32\x11.oracle.v1.ReportB\x04\xc8\xde\x1f\x00\x12!\n\x06result\x18\x03 \x01(\x0b\x32\x11.oracle.v1.Result\"8\n\x1bQueryPendingRequestsRequest\x12\x19\n\x11validator_address\x18\x01 \x01(\t\"C\n\x1cQueryPendingRequestsResponse\x12#\n\x0brequest_ids\x18\x01 \x03(\x03\x42\x0e\xe2\xde\x1f\nRequestIDs\"\x14\n\x12QueryParamsRequest\">\n\x13QueryParamsResponse\x12\'\n\x06params\x18\x01 \x01(\x0b\x32\x11.oracle.v1.ParamsB\x04\xc8\xde\x1f\x00\"2\n\x15QueryValidatorRequest\x12\x19\n\x11validator_address\x18\x01 \x01(\t\"D\n\x16QueryValidatorResponse\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x1a.oracle.v1.ValidatorStatus\"2\n\x15QueryReportersRequest\x12\x19\n\x11validator_address\x18\x01 \x01(\t\"*\n\x16QueryReportersResponse\x12\x10\n\x08reporter\x18\x01 \x03(\t\"\x1e\n\x1cQueryActiveValidatorsRequest\"O\n\x1dQueryActiveValidatorsResponse\x12.\n\nvalidators\x18\x01 \x03(\x0b\x32\x1a.oracle.v1.ActiveValidator\"m\n\x19QueryRequestSearchRequest\x12\x18\n\x10oracle_script_id\x18\x01 \x01(\x03\x12\x10\n\x08\x63\x61lldata\x18\x02 \x01(\t\x12\x11\n\task_count\x18\x03 \x01(\x04\x12\x11\n\tmin_count\x18\x04 \x01(\x04\"N\n\x1aQueryRequestSearchResponse\x12\x30\n\x07request\x18\x01 \x01(\x0b\x32\x1f.oracle.v1.QueryRequestResponse\"Q\n\x18QueryRequestPriceRequest\x12\x0f\n\x07symbols\x18\x01 \x03(\t\x12\x11\n\task_count\x18\x02 \x01(\x03\x12\x11\n\tmin_count\x18\x03 \x01(\x03\"J\n\x19QueryRequestPriceResponse\x12-\n\rprice_results\x18\x01 \x03(\x0b\x32\x16.oracle.v1.PriceResult\"\x94\x01\n\x1fQueryRequestVerificationRequest\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\t\x12\x11\n\tvalidator\x18\x02 \x01(\t\x12\x12\n\nrequest_id\x18\x03 \x01(\x03\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\x03\x12\x10\n\x08reporter\x18\x05 \x01(\t\x12\x11\n\tsignature\x18\x06 \x01(\x0c\"\x88\x01\n QueryRequestVerificationResponse\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\t\x12\x11\n\tvalidator\x18\x02 \x01(\t\x12\x12\n\nrequest_id\x18\x03 \x01(\x03\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\x03\x12\x16\n\x0e\x64\x61ta_source_id\x18\x05 \x01(\x03\"S\n\x17QueryRequestPoolRequest\x12\x13\n\x0brequest_key\x18\x01 \x01(\t\x12\x0f\n\x07port_id\x18\x02 \x01(\t\x12\x12\n\nchannel_id\x18\x03 \x01(\t\"\x96\x01\n\x18QueryRequestPoolResponse\x12\x1c\n\x14request_pool_address\x18\x01 \x01(\t\x12\\\n\x07\x62\x61lance\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins2\xb0\x0e\n\x05Query\x12\x62\n\x06\x43ounts\x12\x1d.oracle.v1.QueryCountsRequest\x1a\x1e.oracle.v1.QueryCountsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/oracle/v1/counts\x12\x66\n\x04\x44\x61ta\x12\x1b.oracle.v1.QueryDataRequest\x1a\x1c.oracle.v1.QueryDataResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/oracle/v1/data/{data_hash}\x12\x85\x01\n\nDataSource\x12!.oracle.v1.QueryDataSourceRequest\x1a\".oracle.v1.QueryDataSourceResponse\"0\x82\xd3\xe4\x93\x02*\x12(/oracle/v1/data_sources/{data_source_id}\x12\x8f\x01\n\x0cOracleScript\x12#.oracle.v1.QueryOracleScriptRequest\x1a$.oracle.v1.QueryOracleScriptResponse\"4\x82\xd3\xe4\x93\x02.\x12,/oracle/v1/oracle_scripts/{oracle_script_id}\x12t\n\x07Request\x12\x1e.oracle.v1.QueryRequestRequest\x1a\x1f.oracle.v1.QueryRequestResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /oracle/v1/requests/{request_id}\x12\x9b\x01\n\x0fPendingRequests\x12&.oracle.v1.QueryPendingRequestsRequest\x1a\'.oracle.v1.QueryPendingRequestsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//oracle/v1/pending_requests/{validator_address}\x12\x83\x01\n\tValidator\x12 .oracle.v1.QueryValidatorRequest\x1a!.oracle.v1.QueryValidatorResponse\"1\x82\xd3\xe4\x93\x02+\x12)/oracle/v1/validators/{validator_address}\x12\x82\x01\n\tReporters\x12 .oracle.v1.QueryReportersRequest\x1a!.oracle.v1.QueryReportersResponse\"0\x82\xd3\xe4\x93\x02*\x12(/oracle/v1/reporters/{validator_address}\x12\x8b\x01\n\x10\x41\x63tiveValidators\x12\'.oracle.v1.QueryActiveValidatorsRequest\x1a(.oracle.v1.QueryActiveValidatorsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/oracle/v1/active_validators\x12\x62\n\x06Params\x12\x1d.oracle.v1.QueryParamsRequest\x1a\x1e.oracle.v1.QueryParamsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/oracle/v1/params\x12\x7f\n\rRequestSearch\x12$.oracle.v1.QueryRequestSearchRequest\x1a%.oracle.v1.QueryRequestSearchResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/oracle/v1/request_search\x12|\n\x0cRequestPrice\x12#.oracle.v1.QueryRequestPriceRequest\x1a$.oracle.v1.QueryRequestPriceResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/oracle/v1/request_prices\x12\x91\x01\n\x13RequestVerification\x12*.oracle.v1.QueryRequestVerificationRequest\x1a+.oracle.v1.QueryRequestVerificationResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/oracle/v1/verify_request\x12\x9c\x01\n\x0bRequestPool\x12\".oracle.v1.QueryRequestPoolRequest\x1a#.oracle.v1.QueryRequestPoolResponse\"D\x82\xd3\xe4\x93\x02>\x12</oracle/v1/request_pool/{request_key}/{port_id}/{channel_id}B.Z,github.com/bandprotocol/chain/x/oracle/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,oracle_dot_v1_dot_oracle__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_QUERYCOUNTSREQUEST = _descriptor.Descriptor(
  name='QueryCountsRequest',
  full_name='oracle.v1.QueryCountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=164,
)


_QUERYCOUNTSRESPONSE = _descriptor.Descriptor(
  name='QueryCountsResponse',
  full_name='oracle.v1.QueryCountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_source_count', full_name='oracle.v1.QueryCountsResponse.data_source_count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_script_count', full_name='oracle.v1.QueryCountsResponse.oracle_script_count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_count', full_name='oracle.v1.QueryCountsResponse.request_count', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=266,
)


_QUERYDATAREQUEST = _descriptor.Descriptor(
  name='QueryDataRequest',
  full_name='oracle.v1.QueryDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_hash', full_name='oracle.v1.QueryDataRequest.data_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=305,
)


_QUERYDATARESPONSE = _descriptor.Descriptor(
  name='QueryDataResponse',
  full_name='oracle.v1.QueryDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='oracle.v1.QueryDataResponse.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=307,
  serialized_end=340,
)


_QUERYDATASOURCEREQUEST = _descriptor.Descriptor(
  name='QueryDataSourceRequest',
  full_name='oracle.v1.QueryDataSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_source_id', full_name='oracle.v1.QueryDataSourceRequest.data_source_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=390,
)


_QUERYDATASOURCERESPONSE = _descriptor.Descriptor(
  name='QueryDataSourceResponse',
  full_name='oracle.v1.QueryDataSourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_source', full_name='oracle.v1.QueryDataSourceResponse.data_source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=392,
  serialized_end=461,
)


_QUERYORACLESCRIPTREQUEST = _descriptor.Descriptor(
  name='QueryOracleScriptRequest',
  full_name='oracle.v1.QueryOracleScriptRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='oracle.v1.QueryOracleScriptRequest.oracle_script_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=515,
)


_QUERYORACLESCRIPTRESPONSE = _descriptor.Descriptor(
  name='QueryOracleScriptResponse',
  full_name='oracle.v1.QueryOracleScriptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle_script', full_name='oracle.v1.QueryOracleScriptResponse.oracle_script', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=517,
  serialized_end=592,
)


_QUERYREQUESTREQUEST = _descriptor.Descriptor(
  name='QueryRequestRequest',
  full_name='oracle.v1.QueryRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.QueryRequestRequest.request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=594,
  serialized_end=635,
)


_QUERYREQUESTRESPONSE = _descriptor.Descriptor(
  name='QueryRequestResponse',
  full_name='oracle.v1.QueryRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='oracle.v1.QueryRequestResponse.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reports', full_name='oracle.v1.QueryRequestResponse.reports', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='oracle.v1.QueryRequestResponse.result', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=638,
  serialized_end=774,
)


_QUERYPENDINGREQUESTSREQUEST = _descriptor.Descriptor(
  name='QueryPendingRequestsRequest',
  full_name='oracle.v1.QueryPendingRequestsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_address', full_name='oracle.v1.QueryPendingRequestsRequest.validator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=776,
  serialized_end=832,
)


_QUERYPENDINGREQUESTSRESPONSE = _descriptor.Descriptor(
  name='QueryPendingRequestsResponse',
  full_name='oracle.v1.QueryPendingRequestsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_ids', full_name='oracle.v1.QueryPendingRequestsResponse.request_ids', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\nRequestIDs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=901,
)


_QUERYPARAMSREQUEST = _descriptor.Descriptor(
  name='QueryParamsRequest',
  full_name='oracle.v1.QueryParamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=903,
  serialized_end=923,
)


_QUERYPARAMSRESPONSE = _descriptor.Descriptor(
  name='QueryParamsResponse',
  full_name='oracle.v1.QueryParamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='oracle.v1.QueryParamsResponse.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=925,
  serialized_end=987,
)


_QUERYVALIDATORREQUEST = _descriptor.Descriptor(
  name='QueryValidatorRequest',
  full_name='oracle.v1.QueryValidatorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_address', full_name='oracle.v1.QueryValidatorRequest.validator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=989,
  serialized_end=1039,
)


_QUERYVALIDATORRESPONSE = _descriptor.Descriptor(
  name='QueryValidatorResponse',
  full_name='oracle.v1.QueryValidatorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='oracle.v1.QueryValidatorResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1041,
  serialized_end=1109,
)


_QUERYREPORTERSREQUEST = _descriptor.Descriptor(
  name='QueryReportersRequest',
  full_name='oracle.v1.QueryReportersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_address', full_name='oracle.v1.QueryReportersRequest.validator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1111,
  serialized_end=1161,
)


_QUERYREPORTERSRESPONSE = _descriptor.Descriptor(
  name='QueryReportersResponse',
  full_name='oracle.v1.QueryReportersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reporter', full_name='oracle.v1.QueryReportersResponse.reporter', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1163,
  serialized_end=1205,
)


_QUERYACTIVEVALIDATORSREQUEST = _descriptor.Descriptor(
  name='QueryActiveValidatorsRequest',
  full_name='oracle.v1.QueryActiveValidatorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1207,
  serialized_end=1237,
)


_QUERYACTIVEVALIDATORSRESPONSE = _descriptor.Descriptor(
  name='QueryActiveValidatorsResponse',
  full_name='oracle.v1.QueryActiveValidatorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validators', full_name='oracle.v1.QueryActiveValidatorsResponse.validators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1239,
  serialized_end=1318,
)


_QUERYREQUESTSEARCHREQUEST = _descriptor.Descriptor(
  name='QueryRequestSearchRequest',
  full_name='oracle.v1.QueryRequestSearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='oracle.v1.QueryRequestSearchRequest.oracle_script_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calldata', full_name='oracle.v1.QueryRequestSearchRequest.calldata', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_count', full_name='oracle.v1.QueryRequestSearchRequest.ask_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='oracle.v1.QueryRequestSearchRequest.min_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1320,
  serialized_end=1429,
)


_QUERYREQUESTSEARCHRESPONSE = _descriptor.Descriptor(
  name='QueryRequestSearchResponse',
  full_name='oracle.v1.QueryRequestSearchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='oracle.v1.QueryRequestSearchResponse.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1431,
  serialized_end=1509,
)


_QUERYREQUESTPRICEREQUEST = _descriptor.Descriptor(
  name='QueryRequestPriceRequest',
  full_name='oracle.v1.QueryRequestPriceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbols', full_name='oracle.v1.QueryRequestPriceRequest.symbols', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_count', full_name='oracle.v1.QueryRequestPriceRequest.ask_count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='oracle.v1.QueryRequestPriceRequest.min_count', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1511,
  serialized_end=1592,
)


_QUERYREQUESTPRICERESPONSE = _descriptor.Descriptor(
  name='QueryRequestPriceResponse',
  full_name='oracle.v1.QueryRequestPriceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price_results', full_name='oracle.v1.QueryRequestPriceResponse.price_results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1594,
  serialized_end=1668,
)


_QUERYREQUESTVERIFICATIONREQUEST = _descriptor.Descriptor(
  name='QueryRequestVerificationRequest',
  full_name='oracle.v1.QueryRequestVerificationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='oracle.v1.QueryRequestVerificationRequest.chain_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.QueryRequestVerificationRequest.validator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.QueryRequestVerificationRequest.request_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_id', full_name='oracle.v1.QueryRequestVerificationRequest.external_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reporter', full_name='oracle.v1.QueryRequestVerificationRequest.reporter', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='oracle.v1.QueryRequestVerificationRequest.signature', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1671,
  serialized_end=1819,
)


_QUERYREQUESTVERIFICATIONRESPONSE = _descriptor.Descriptor(
  name='QueryRequestVerificationResponse',
  full_name='oracle.v1.QueryRequestVerificationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='oracle.v1.QueryRequestVerificationResponse.chain_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.QueryRequestVerificationResponse.validator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.QueryRequestVerificationResponse.request_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_id', full_name='oracle.v1.QueryRequestVerificationResponse.external_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_id', full_name='oracle.v1.QueryRequestVerificationResponse.data_source_id', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1822,
  serialized_end=1958,
)


_QUERYREQUESTPOOLREQUEST = _descriptor.Descriptor(
  name='QueryRequestPoolRequest',
  full_name='oracle.v1.QueryRequestPoolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_key', full_name='oracle.v1.QueryRequestPoolRequest.request_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_id', full_name='oracle.v1.QueryRequestPoolRequest.port_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='oracle.v1.QueryRequestPoolRequest.channel_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1960,
  serialized_end=2043,
)


_QUERYREQUESTPOOLRESPONSE = _descriptor.Descriptor(
  name='QueryRequestPoolResponse',
  full_name='oracle.v1.QueryRequestPoolResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_pool_address', full_name='oracle.v1.QueryRequestPoolResponse.request_pool_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance', full_name='oracle.v1.QueryRequestPoolResponse.balance', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2046,
  serialized_end=2196,
)

_QUERYDATASOURCERESPONSE.fields_by_name['data_source'].message_type = oracle_dot_v1_dot_oracle__pb2._DATASOURCE
_QUERYORACLESCRIPTRESPONSE.fields_by_name['oracle_script'].message_type = oracle_dot_v1_dot_oracle__pb2._ORACLESCRIPT
_QUERYREQUESTRESPONSE.fields_by_name['request'].message_type = oracle_dot_v1_dot_oracle__pb2._REQUEST
_QUERYREQUESTRESPONSE.fields_by_name['reports'].message_type = oracle_dot_v1_dot_oracle__pb2._REPORT
_QUERYREQUESTRESPONSE.fields_by_name['result'].message_type = oracle_dot_v1_dot_oracle__pb2._RESULT
_QUERYPARAMSRESPONSE.fields_by_name['params'].message_type = oracle_dot_v1_dot_oracle__pb2._PARAMS
_QUERYVALIDATORRESPONSE.fields_by_name['status'].message_type = oracle_dot_v1_dot_oracle__pb2._VALIDATORSTATUS
_QUERYACTIVEVALIDATORSRESPONSE.fields_by_name['validators'].message_type = oracle_dot_v1_dot_oracle__pb2._ACTIVEVALIDATOR
_QUERYREQUESTSEARCHRESPONSE.fields_by_name['request'].message_type = _QUERYREQUESTRESPONSE
_QUERYREQUESTPRICERESPONSE.fields_by_name['price_results'].message_type = oracle_dot_v1_dot_oracle__pb2._PRICERESULT
_QUERYREQUESTPOOLRESPONSE.fields_by_name['balance'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['QueryCountsRequest'] = _QUERYCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['QueryCountsResponse'] = _QUERYCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['QueryDataRequest'] = _QUERYDATAREQUEST
DESCRIPTOR.message_types_by_name['QueryDataResponse'] = _QUERYDATARESPONSE
DESCRIPTOR.message_types_by_name['QueryDataSourceRequest'] = _QUERYDATASOURCEREQUEST
DESCRIPTOR.message_types_by_name['QueryDataSourceResponse'] = _QUERYDATASOURCERESPONSE
DESCRIPTOR.message_types_by_name['QueryOracleScriptRequest'] = _QUERYORACLESCRIPTREQUEST
DESCRIPTOR.message_types_by_name['QueryOracleScriptResponse'] = _QUERYORACLESCRIPTRESPONSE
DESCRIPTOR.message_types_by_name['QueryRequestRequest'] = _QUERYREQUESTREQUEST
DESCRIPTOR.message_types_by_name['QueryRequestResponse'] = _QUERYREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['QueryPendingRequestsRequest'] = _QUERYPENDINGREQUESTSREQUEST
DESCRIPTOR.message_types_by_name['QueryPendingRequestsResponse'] = _QUERYPENDINGREQUESTSRESPONSE
DESCRIPTOR.message_types_by_name['QueryParamsRequest'] = _QUERYPARAMSREQUEST
DESCRIPTOR.message_types_by_name['QueryParamsResponse'] = _QUERYPARAMSRESPONSE
DESCRIPTOR.message_types_by_name['QueryValidatorRequest'] = _QUERYVALIDATORREQUEST
DESCRIPTOR.message_types_by_name['QueryValidatorResponse'] = _QUERYVALIDATORRESPONSE
DESCRIPTOR.message_types_by_name['QueryReportersRequest'] = _QUERYREPORTERSREQUEST
DESCRIPTOR.message_types_by_name['QueryReportersResponse'] = _QUERYREPORTERSRESPONSE
DESCRIPTOR.message_types_by_name['QueryActiveValidatorsRequest'] = _QUERYACTIVEVALIDATORSREQUEST
DESCRIPTOR.message_types_by_name['QueryActiveValidatorsResponse'] = _QUERYACTIVEVALIDATORSRESPONSE
DESCRIPTOR.message_types_by_name['QueryRequestSearchRequest'] = _QUERYREQUESTSEARCHREQUEST
DESCRIPTOR.message_types_by_name['QueryRequestSearchResponse'] = _QUERYREQUESTSEARCHRESPONSE
DESCRIPTOR.message_types_by_name['QueryRequestPriceRequest'] = _QUERYREQUESTPRICEREQUEST
DESCRIPTOR.message_types_by_name['QueryRequestPriceResponse'] = _QUERYREQUESTPRICERESPONSE
DESCRIPTOR.message_types_by_name['QueryRequestVerificationRequest'] = _QUERYREQUESTVERIFICATIONREQUEST
DESCRIPTOR.message_types_by_name['QueryRequestVerificationResponse'] = _QUERYREQUESTVERIFICATIONRESPONSE
DESCRIPTOR.message_types_by_name['QueryRequestPoolRequest'] = _QUERYREQUESTPOOLREQUEST
DESCRIPTOR.message_types_by_name['QueryRequestPoolResponse'] = _QUERYREQUESTPOOLRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryCountsRequest = _reflection.GeneratedProtocolMessageType('QueryCountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCOUNTSREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryCountsRequest)
  })
_sym_db.RegisterMessage(QueryCountsRequest)

QueryCountsResponse = _reflection.GeneratedProtocolMessageType('QueryCountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCOUNTSRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryCountsResponse)
  })
_sym_db.RegisterMessage(QueryCountsResponse)

QueryDataRequest = _reflection.GeneratedProtocolMessageType('QueryDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDATAREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryDataRequest)
  })
_sym_db.RegisterMessage(QueryDataRequest)

QueryDataResponse = _reflection.GeneratedProtocolMessageType('QueryDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDATARESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryDataResponse)
  })
_sym_db.RegisterMessage(QueryDataResponse)

QueryDataSourceRequest = _reflection.GeneratedProtocolMessageType('QueryDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDATASOURCEREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryDataSourceRequest)
  })
_sym_db.RegisterMessage(QueryDataSourceRequest)

QueryDataSourceResponse = _reflection.GeneratedProtocolMessageType('QueryDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDATASOURCERESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryDataSourceResponse)
  })
_sym_db.RegisterMessage(QueryDataSourceResponse)

QueryOracleScriptRequest = _reflection.GeneratedProtocolMessageType('QueryOracleScriptRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORACLESCRIPTREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryOracleScriptRequest)
  })
_sym_db.RegisterMessage(QueryOracleScriptRequest)

QueryOracleScriptResponse = _reflection.GeneratedProtocolMessageType('QueryOracleScriptResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORACLESCRIPTRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryOracleScriptResponse)
  })
_sym_db.RegisterMessage(QueryOracleScriptResponse)

QueryRequestRequest = _reflection.GeneratedProtocolMessageType('QueryRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestRequest)
  })
_sym_db.RegisterMessage(QueryRequestRequest)

QueryRequestResponse = _reflection.GeneratedProtocolMessageType('QueryRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestResponse)
  })
_sym_db.RegisterMessage(QueryRequestResponse)

QueryPendingRequestsRequest = _reflection.GeneratedProtocolMessageType('QueryPendingRequestsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPENDINGREQUESTSREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryPendingRequestsRequest)
  })
_sym_db.RegisterMessage(QueryPendingRequestsRequest)

QueryPendingRequestsResponse = _reflection.GeneratedProtocolMessageType('QueryPendingRequestsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPENDINGREQUESTSRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryPendingRequestsResponse)
  })
_sym_db.RegisterMessage(QueryPendingRequestsResponse)

QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

QueryValidatorRequest = _reflection.GeneratedProtocolMessageType('QueryValidatorRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryValidatorRequest)
  })
_sym_db.RegisterMessage(QueryValidatorRequest)

QueryValidatorResponse = _reflection.GeneratedProtocolMessageType('QueryValidatorResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryValidatorResponse)
  })
_sym_db.RegisterMessage(QueryValidatorResponse)

QueryReportersRequest = _reflection.GeneratedProtocolMessageType('QueryReportersRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREPORTERSREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryReportersRequest)
  })
_sym_db.RegisterMessage(QueryReportersRequest)

QueryReportersResponse = _reflection.GeneratedProtocolMessageType('QueryReportersResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREPORTERSRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryReportersResponse)
  })
_sym_db.RegisterMessage(QueryReportersResponse)

QueryActiveValidatorsRequest = _reflection.GeneratedProtocolMessageType('QueryActiveValidatorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYACTIVEVALIDATORSREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryActiveValidatorsRequest)
  })
_sym_db.RegisterMessage(QueryActiveValidatorsRequest)

QueryActiveValidatorsResponse = _reflection.GeneratedProtocolMessageType('QueryActiveValidatorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYACTIVEVALIDATORSRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryActiveValidatorsResponse)
  })
_sym_db.RegisterMessage(QueryActiveValidatorsResponse)

QueryRequestSearchRequest = _reflection.GeneratedProtocolMessageType('QueryRequestSearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTSEARCHREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestSearchRequest)
  })
_sym_db.RegisterMessage(QueryRequestSearchRequest)

QueryRequestSearchResponse = _reflection.GeneratedProtocolMessageType('QueryRequestSearchResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTSEARCHRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestSearchResponse)
  })
_sym_db.RegisterMessage(QueryRequestSearchResponse)

QueryRequestPriceRequest = _reflection.GeneratedProtocolMessageType('QueryRequestPriceRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTPRICEREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestPriceRequest)
  })
_sym_db.RegisterMessage(QueryRequestPriceRequest)

QueryRequestPriceResponse = _reflection.GeneratedProtocolMessageType('QueryRequestPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTPRICERESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestPriceResponse)
  })
_sym_db.RegisterMessage(QueryRequestPriceResponse)

QueryRequestVerificationRequest = _reflection.GeneratedProtocolMessageType('QueryRequestVerificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTVERIFICATIONREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestVerificationRequest)
  })
_sym_db.RegisterMessage(QueryRequestVerificationRequest)

QueryRequestVerificationResponse = _reflection.GeneratedProtocolMessageType('QueryRequestVerificationResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTVERIFICATIONRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestVerificationResponse)
  })
_sym_db.RegisterMessage(QueryRequestVerificationResponse)

QueryRequestPoolRequest = _reflection.GeneratedProtocolMessageType('QueryRequestPoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTPOOLREQUEST,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestPoolRequest)
  })
_sym_db.RegisterMessage(QueryRequestPoolRequest)

QueryRequestPoolResponse = _reflection.GeneratedProtocolMessageType('QueryRequestPoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUESTPOOLRESPONSE,
  '__module__' : 'oracle.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.QueryRequestPoolResponse)
  })
_sym_db.RegisterMessage(QueryRequestPoolResponse)


DESCRIPTOR._options = None
_QUERYREQUESTRESPONSE.fields_by_name['reports']._options = None
_QUERYPENDINGREQUESTSRESPONSE.fields_by_name['request_ids']._options = None
_QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
_QUERYREQUESTPOOLRESPONSE.fields_by_name['balance']._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='oracle.v1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2199,
  serialized_end=4039,
  methods=[
  _descriptor.MethodDescriptor(
    name='Counts',
    full_name='oracle.v1.Query.Counts',
    index=0,
    containing_service=None,
    input_type=_QUERYCOUNTSREQUEST,
    output_type=_QUERYCOUNTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/oracle/v1/counts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Data',
    full_name='oracle.v1.Query.Data',
    index=1,
    containing_service=None,
    input_type=_QUERYDATAREQUEST,
    output_type=_QUERYDATARESPONSE,
    serialized_options=b'\202\323\344\223\002\035\022\033/oracle/v1/data/{data_hash}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DataSource',
    full_name='oracle.v1.Query.DataSource',
    index=2,
    containing_service=None,
    input_type=_QUERYDATASOURCEREQUEST,
    output_type=_QUERYDATASOURCERESPONSE,
    serialized_options=b'\202\323\344\223\002*\022(/oracle/v1/data_sources/{data_source_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OracleScript',
    full_name='oracle.v1.Query.OracleScript',
    index=3,
    containing_service=None,
    input_type=_QUERYORACLESCRIPTREQUEST,
    output_type=_QUERYORACLESCRIPTRESPONSE,
    serialized_options=b'\202\323\344\223\002.\022,/oracle/v1/oracle_scripts/{oracle_script_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Request',
    full_name='oracle.v1.Query.Request',
    index=4,
    containing_service=None,
    input_type=_QUERYREQUESTREQUEST,
    output_type=_QUERYREQUESTRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /oracle/v1/requests/{request_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PendingRequests',
    full_name='oracle.v1.Query.PendingRequests',
    index=5,
    containing_service=None,
    input_type=_QUERYPENDINGREQUESTSREQUEST,
    output_type=_QUERYPENDINGREQUESTSRESPONSE,
    serialized_options=b'\202\323\344\223\0021\022//oracle/v1/pending_requests/{validator_address}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Validator',
    full_name='oracle.v1.Query.Validator',
    index=6,
    containing_service=None,
    input_type=_QUERYVALIDATORREQUEST,
    output_type=_QUERYVALIDATORRESPONSE,
    serialized_options=b'\202\323\344\223\002+\022)/oracle/v1/validators/{validator_address}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Reporters',
    full_name='oracle.v1.Query.Reporters',
    index=7,
    containing_service=None,
    input_type=_QUERYREPORTERSREQUEST,
    output_type=_QUERYREPORTERSRESPONSE,
    serialized_options=b'\202\323\344\223\002*\022(/oracle/v1/reporters/{validator_address}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ActiveValidators',
    full_name='oracle.v1.Query.ActiveValidators',
    index=8,
    containing_service=None,
    input_type=_QUERYACTIVEVALIDATORSREQUEST,
    output_type=_QUERYACTIVEVALIDATORSRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/oracle/v1/active_validators',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Params',
    full_name='oracle.v1.Query.Params',
    index=9,
    containing_service=None,
    input_type=_QUERYPARAMSREQUEST,
    output_type=_QUERYPARAMSRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/oracle/v1/params',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestSearch',
    full_name='oracle.v1.Query.RequestSearch',
    index=10,
    containing_service=None,
    input_type=_QUERYREQUESTSEARCHREQUEST,
    output_type=_QUERYREQUESTSEARCHRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/oracle/v1/request_search',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestPrice',
    full_name='oracle.v1.Query.RequestPrice',
    index=11,
    containing_service=None,
    input_type=_QUERYREQUESTPRICEREQUEST,
    output_type=_QUERYREQUESTPRICERESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/oracle/v1/request_prices',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestVerification',
    full_name='oracle.v1.Query.RequestVerification',
    index=12,
    containing_service=None,
    input_type=_QUERYREQUESTVERIFICATIONREQUEST,
    output_type=_QUERYREQUESTVERIFICATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/oracle/v1/verify_request',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestPool',
    full_name='oracle.v1.Query.RequestPool',
    index=13,
    containing_service=None,
    input_type=_QUERYREQUESTPOOLREQUEST,
    output_type=_QUERYREQUESTPOOLRESPONSE,
    serialized_options=b'\202\323\344\223\002>\022</oracle/v1/request_pool/{request_key}/{port_id}/{channel_id}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)
