"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ClientState:grpc.UnaryUnaryMultiCallable[
        global___QueryClientStateRequest,
        global___QueryClientStateResponse] = ...

    ClientStates:grpc.UnaryUnaryMultiCallable[
        global___QueryClientStatesRequest,
        global___QueryClientStatesResponse] = ...

    ConsensusState:grpc.UnaryUnaryMultiCallable[
        global___QueryConsensusStateRequest,
        global___QueryConsensusStateResponse] = ...

    ConsensusStates:grpc.UnaryUnaryMultiCallable[
        global___QueryConsensusStatesRequest,
        global___QueryConsensusStatesResponse] = ...

    ClientParams:grpc.UnaryUnaryMultiCallable[
        global___QueryClientParamsRequest,
        global___QueryClientParamsResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ClientState(self,
        request: global___QueryClientStateRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryClientStateResponse: ...

    @abc.abstractmethod
    def ClientStates(self,
        request: global___QueryClientStatesRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryClientStatesResponse: ...

    @abc.abstractmethod
    def ConsensusState(self,
        request: global___QueryConsensusStateRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryConsensusStateResponse: ...

    @abc.abstractmethod
    def ConsensusStates(self,
        request: global___QueryConsensusStatesRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryConsensusStatesResponse: ...

    @abc.abstractmethod
    def ClientParams(self,
        request: global___QueryClientParamsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryClientParamsResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
