"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class ServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetNodeInfo:grpc.UnaryUnaryMultiCallable[
        global___GetNodeInfoRequest,
        global___GetNodeInfoResponse] = ...

    GetSyncing:grpc.UnaryUnaryMultiCallable[
        global___GetSyncingRequest,
        global___GetSyncingResponse] = ...

    GetLatestBlock:grpc.UnaryUnaryMultiCallable[
        global___GetLatestBlockRequest,
        global___GetLatestBlockResponse] = ...

    GetBlockByHeight:grpc.UnaryUnaryMultiCallable[
        global___GetBlockByHeightRequest,
        global___GetBlockByHeightResponse] = ...

    GetLatestValidatorSet:grpc.UnaryUnaryMultiCallable[
        global___GetLatestValidatorSetRequest,
        global___GetLatestValidatorSetResponse] = ...

    GetValidatorSetByHeight:grpc.UnaryUnaryMultiCallable[
        global___GetValidatorSetByHeightRequest,
        global___GetValidatorSetByHeightResponse] = ...


class ServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetNodeInfo(self,
        request: global___GetNodeInfoRequest,
        context: grpc.ServicerContext,
    ) -> global___GetNodeInfoResponse: ...

    @abc.abstractmethod
    def GetSyncing(self,
        request: global___GetSyncingRequest,
        context: grpc.ServicerContext,
    ) -> global___GetSyncingResponse: ...

    @abc.abstractmethod
    def GetLatestBlock(self,
        request: global___GetLatestBlockRequest,
        context: grpc.ServicerContext,
    ) -> global___GetLatestBlockResponse: ...

    @abc.abstractmethod
    def GetBlockByHeight(self,
        request: global___GetBlockByHeightRequest,
        context: grpc.ServicerContext,
    ) -> global___GetBlockByHeightResponse: ...

    @abc.abstractmethod
    def GetLatestValidatorSet(self,
        request: global___GetLatestValidatorSetRequest,
        context: grpc.ServicerContext,
    ) -> global___GetLatestValidatorSetResponse: ...

    @abc.abstractmethod
    def GetValidatorSetByHeight(self,
        request: global___GetValidatorSetByHeightRequest,
        context: grpc.ServicerContext,
    ) -> global___GetValidatorSetByHeightResponse: ...


def add_ServiceServicer_to_server(servicer: ServiceServicer, server: grpc.Server) -> None: ...
