"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.gov.v1beta1.gov_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryProposalRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"proposal_id",b"proposal_id"]) -> None: ...
global___QueryProposalRequest = QueryProposalRequest

class QueryProposalResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_FIELD_NUMBER: builtins.int

    @property
    def proposal(self) -> cosmos.gov.v1beta1.gov_pb2.Proposal: ...

    def __init__(self,
        *,
        proposal : typing.Optional[cosmos.gov.v1beta1.gov_pb2.Proposal] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proposal",b"proposal"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"proposal",b"proposal"]) -> None: ...
global___QueryProposalResponse = QueryProposalResponse

class QueryProposalsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_STATUS_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    proposal_status: cosmos.gov.v1beta1.gov_pb2.ProposalStatus.V = ...
    voter: typing.Text = ...
    depositor: typing.Text = ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        proposal_status : cosmos.gov.v1beta1.gov_pb2.ProposalStatus.V = ...,
        voter : typing.Text = ...,
        depositor : typing.Text = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"depositor",b"depositor",u"pagination",b"pagination",u"proposal_status",b"proposal_status",u"voter",b"voter"]) -> None: ...
global___QueryProposalsRequest = QueryProposalsRequest

class QueryProposalsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSALS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def proposals(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Proposal]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    def __init__(self,
        *,
        proposals : typing.Optional[typing.Iterable[cosmos.gov.v1beta1.gov_pb2.Proposal]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination",u"proposals",b"proposals"]) -> None: ...
global___QueryProposalsResponse = QueryProposalsResponse

class QueryVoteRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...
    voter: typing.Text = ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        voter : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"proposal_id",b"proposal_id",u"voter",b"voter"]) -> None: ...
global___QueryVoteRequest = QueryVoteRequest

class QueryVoteResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VOTE_FIELD_NUMBER: builtins.int

    @property
    def vote(self) -> cosmos.gov.v1beta1.gov_pb2.Vote: ...

    def __init__(self,
        *,
        vote : typing.Optional[cosmos.gov.v1beta1.gov_pb2.Vote] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"vote",b"vote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"vote",b"vote"]) -> None: ...
global___QueryVoteResponse = QueryVoteResponse

class QueryVotesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination",u"proposal_id",b"proposal_id"]) -> None: ...
global___QueryVotesRequest = QueryVotesRequest

class QueryVotesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VOTES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def votes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Vote]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    def __init__(self,
        *,
        votes : typing.Optional[typing.Iterable[cosmos.gov.v1beta1.gov_pb2.Vote]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination",u"votes",b"votes"]) -> None: ...
global___QueryVotesResponse = QueryVotesResponse

class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_TYPE_FIELD_NUMBER: builtins.int
    params_type: typing.Text = ...

    def __init__(self,
        *,
        params_type : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"params_type",b"params_type"]) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VOTING_PARAMS_FIELD_NUMBER: builtins.int
    DEPOSIT_PARAMS_FIELD_NUMBER: builtins.int
    TALLY_PARAMS_FIELD_NUMBER: builtins.int

    @property
    def voting_params(self) -> cosmos.gov.v1beta1.gov_pb2.VotingParams: ...

    @property
    def deposit_params(self) -> cosmos.gov.v1beta1.gov_pb2.DepositParams: ...

    @property
    def tally_params(self) -> cosmos.gov.v1beta1.gov_pb2.TallyParams: ...

    def __init__(self,
        *,
        voting_params : typing.Optional[cosmos.gov.v1beta1.gov_pb2.VotingParams] = ...,
        deposit_params : typing.Optional[cosmos.gov.v1beta1.gov_pb2.DepositParams] = ...,
        tally_params : typing.Optional[cosmos.gov.v1beta1.gov_pb2.TallyParams] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"deposit_params",b"deposit_params",u"tally_params",b"tally_params",u"voting_params",b"voting_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"deposit_params",b"deposit_params",u"tally_params",b"tally_params",u"voting_params",b"voting_params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse

class QueryDepositRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...
    depositor: typing.Text = ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        depositor : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"depositor",b"depositor",u"proposal_id",b"proposal_id"]) -> None: ...
global___QueryDepositRequest = QueryDepositRequest

class QueryDepositResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DEPOSIT_FIELD_NUMBER: builtins.int

    @property
    def deposit(self) -> cosmos.gov.v1beta1.gov_pb2.Deposit: ...

    def __init__(self,
        *,
        deposit : typing.Optional[cosmos.gov.v1beta1.gov_pb2.Deposit] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"deposit",b"deposit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"deposit",b"deposit"]) -> None: ...
global___QueryDepositResponse = QueryDepositResponse

class QueryDepositsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination",u"proposal_id",b"proposal_id"]) -> None: ...
global___QueryDepositsRequest = QueryDepositsRequest

class QueryDepositsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DEPOSITS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def deposits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Deposit]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    def __init__(self,
        *,
        deposits : typing.Optional[typing.Iterable[cosmos.gov.v1beta1.gov_pb2.Deposit]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"deposits",b"deposits",u"pagination",b"pagination"]) -> None: ...
global___QueryDepositsResponse = QueryDepositsResponse

class QueryTallyResultRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"proposal_id",b"proposal_id"]) -> None: ...
global___QueryTallyResultRequest = QueryTallyResultRequest

class QueryTallyResultResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TALLY_FIELD_NUMBER: builtins.int

    @property
    def tally(self) -> cosmos.gov.v1beta1.gov_pb2.TallyResult: ...

    def __init__(self,
        *,
        tally : typing.Optional[cosmos.gov.v1beta1.gov_pb2.TallyResult] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"tally",b"tally"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"tally",b"tally"]) -> None: ...
global___QueryTallyResultResponse = QueryTallyResultResponse
