"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Connection:grpc.UnaryUnaryMultiCallable[
        global___QueryConnectionRequest,
        global___QueryConnectionResponse] = ...

    Connections:grpc.UnaryUnaryMultiCallable[
        global___QueryConnectionsRequest,
        global___QueryConnectionsResponse] = ...

    ClientConnections:grpc.UnaryUnaryMultiCallable[
        global___QueryClientConnectionsRequest,
        global___QueryClientConnectionsResponse] = ...

    ConnectionClientState:grpc.UnaryUnaryMultiCallable[
        global___QueryConnectionClientStateRequest,
        global___QueryConnectionClientStateResponse] = ...

    ConnectionConsensusState:grpc.UnaryUnaryMultiCallable[
        global___QueryConnectionConsensusStateRequest,
        global___QueryConnectionConsensusStateResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Connection(self,
        request: global___QueryConnectionRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryConnectionResponse: ...

    @abc.abstractmethod
    def Connections(self,
        request: global___QueryConnectionsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryConnectionsResponse: ...

    @abc.abstractmethod
    def ClientConnections(self,
        request: global___QueryClientConnectionsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryClientConnectionsResponse: ...

    @abc.abstractmethod
    def ConnectionClientState(self,
        request: global___QueryConnectionClientStateRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryConnectionClientStateResponse: ...

    @abc.abstractmethod
    def ConnectionConsensusState(self,
        request: global___QueryConnectionConsensusStateRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryConnectionConsensusStateResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
