"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BaseAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    PUB_KEY_FIELD_NUMBER: builtins.int
    ACCOUNT_NUMBER_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    address: typing.Text = ...
    account_number: builtins.int = ...
    sequence: builtins.int = ...

    @property
    def pub_key(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        pub_key : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        account_number : builtins.int = ...,
        sequence : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pub_key",b"pub_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"account_number",b"account_number",u"address",b"address",u"pub_key",b"pub_key",u"sequence",b"sequence"]) -> None: ...
global___BaseAccount = BaseAccount

class ModuleAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BASE_ACCOUNT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    name: typing.Text = ...

    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    @property
    def base_account(self) -> global___BaseAccount: ...

    def __init__(self,
        *,
        base_account : typing.Optional[global___BaseAccount] = ...,
        name : typing.Text = ...,
        permissions : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"base_account",b"base_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"base_account",b"base_account",u"name",b"name",u"permissions",b"permissions"]) -> None: ...
global___ModuleAccount = ModuleAccount

class Params(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MAX_MEMO_CHARACTERS_FIELD_NUMBER: builtins.int
    TX_SIG_LIMIT_FIELD_NUMBER: builtins.int
    TX_SIZE_COST_PER_BYTE_FIELD_NUMBER: builtins.int
    SIG_VERIFY_COST_ED25519_FIELD_NUMBER: builtins.int
    SIG_VERIFY_COST_SECP256K1_FIELD_NUMBER: builtins.int
    max_memo_characters: builtins.int = ...
    tx_sig_limit: builtins.int = ...
    tx_size_cost_per_byte: builtins.int = ...
    sig_verify_cost_ed25519: builtins.int = ...
    sig_verify_cost_secp256k1: builtins.int = ...

    def __init__(self,
        *,
        max_memo_characters : builtins.int = ...,
        tx_sig_limit : builtins.int = ...,
        tx_size_cost_per_byte : builtins.int = ...,
        sig_verify_cost_ed25519 : builtins.int = ...,
        sig_verify_cost_secp256k1 : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"max_memo_characters",b"max_memo_characters",u"sig_verify_cost_ed25519",b"sig_verify_cost_ed25519",u"sig_verify_cost_secp256k1",b"sig_verify_cost_secp256k1",u"tx_sig_limit",b"tx_sig_limit",u"tx_size_cost_per_byte",b"tx_size_cost_per_byte"]) -> None: ...
global___Params = Params
