"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .tx_pb2 import *
class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    CreateClient:grpc.UnaryUnaryMultiCallable[
        global___MsgCreateClient,
        global___MsgCreateClientResponse] = ...

    UpdateClient:grpc.UnaryUnaryMultiCallable[
        global___MsgUpdateClient,
        global___MsgUpdateClientResponse] = ...

    UpgradeClient:grpc.UnaryUnaryMultiCallable[
        global___MsgUpgradeClient,
        global___MsgUpgradeClientResponse] = ...

    SubmitMisbehaviour:grpc.UnaryUnaryMultiCallable[
        global___MsgSubmitMisbehaviour,
        global___MsgSubmitMisbehaviourResponse] = ...


class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateClient(self,
        request: global___MsgCreateClient,
        context: grpc.ServicerContext,
    ) -> global___MsgCreateClientResponse: ...

    @abc.abstractmethod
    def UpdateClient(self,
        request: global___MsgUpdateClient,
        context: grpc.ServicerContext,
    ) -> global___MsgUpdateClientResponse: ...

    @abc.abstractmethod
    def UpgradeClient(self,
        request: global___MsgUpgradeClient,
        context: grpc.ServicerContext,
    ) -> global___MsgUpgradeClientResponse: ...

    @abc.abstractmethod
    def SubmitMisbehaviour(self,
        request: global___MsgSubmitMisbehaviour,
        context: grpc.ServicerContext,
    ) -> global___MsgSubmitMisbehaviourResponse: ...


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...
