"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.query.v1beta1.pagination_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import ibc.applications.transfer.v1.transfer_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryDenomTraceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HASH_FIELD_NUMBER: builtins.int
    hash: typing.Text = ...

    def __init__(self,
        *,
        hash : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"hash",b"hash"]) -> None: ...
global___QueryDenomTraceRequest = QueryDenomTraceRequest

class QueryDenomTraceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DENOM_TRACE_FIELD_NUMBER: builtins.int

    @property
    def denom_trace(self) -> ibc.applications.transfer.v1.transfer_pb2.DenomTrace: ...

    def __init__(self,
        *,
        denom_trace : typing.Optional[ibc.applications.transfer.v1.transfer_pb2.DenomTrace] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"denom_trace",b"denom_trace"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"denom_trace",b"denom_trace"]) -> None: ...
global___QueryDenomTraceResponse = QueryDenomTraceResponse

class QueryDenomTracesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> None: ...
global___QueryDenomTracesRequest = QueryDenomTracesRequest

class QueryDenomTracesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DENOM_TRACES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def denom_traces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.applications.transfer.v1.transfer_pb2.DenomTrace]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    def __init__(self,
        *,
        denom_traces : typing.Optional[typing.Iterable[ibc.applications.transfer.v1.transfer_pb2.DenomTrace]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"denom_traces",b"denom_traces",u"pagination",b"pagination"]) -> None: ...
global___QueryDenomTracesResponse = QueryDenomTracesResponse

class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_FIELD_NUMBER: builtins.int

    @property
    def params(self) -> ibc.applications.transfer.v1.transfer_pb2.Params: ...

    def __init__(self,
        *,
        params : typing.Optional[ibc.applications.transfer.v1.transfer_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse
