"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Channel:grpc.UnaryUnaryMultiCallable[
        global___QueryChannelRequest,
        global___QueryChannelResponse] = ...

    Channels:grpc.UnaryUnaryMultiCallable[
        global___QueryChannelsRequest,
        global___QueryChannelsResponse] = ...

    ConnectionChannels:grpc.UnaryUnaryMultiCallable[
        global___QueryConnectionChannelsRequest,
        global___QueryConnectionChannelsResponse] = ...

    ChannelClientState:grpc.UnaryUnaryMultiCallable[
        global___QueryChannelClientStateRequest,
        global___QueryChannelClientStateResponse] = ...

    ChannelConsensusState:grpc.UnaryUnaryMultiCallable[
        global___QueryChannelConsensusStateRequest,
        global___QueryChannelConsensusStateResponse] = ...

    PacketCommitment:grpc.UnaryUnaryMultiCallable[
        global___QueryPacketCommitmentRequest,
        global___QueryPacketCommitmentResponse] = ...

    PacketCommitments:grpc.UnaryUnaryMultiCallable[
        global___QueryPacketCommitmentsRequest,
        global___QueryPacketCommitmentsResponse] = ...

    PacketReceipt:grpc.UnaryUnaryMultiCallable[
        global___QueryPacketReceiptRequest,
        global___QueryPacketReceiptResponse] = ...

    PacketAcknowledgement:grpc.UnaryUnaryMultiCallable[
        global___QueryPacketAcknowledgementRequest,
        global___QueryPacketAcknowledgementResponse] = ...

    PacketAcknowledgements:grpc.UnaryUnaryMultiCallable[
        global___QueryPacketAcknowledgementsRequest,
        global___QueryPacketAcknowledgementsResponse] = ...

    UnreceivedPackets:grpc.UnaryUnaryMultiCallable[
        global___QueryUnreceivedPacketsRequest,
        global___QueryUnreceivedPacketsResponse] = ...

    UnreceivedAcks:grpc.UnaryUnaryMultiCallable[
        global___QueryUnreceivedAcksRequest,
        global___QueryUnreceivedAcksResponse] = ...

    NextSequenceReceive:grpc.UnaryUnaryMultiCallable[
        global___QueryNextSequenceReceiveRequest,
        global___QueryNextSequenceReceiveResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Channel(self,
        request: global___QueryChannelRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryChannelResponse: ...

    @abc.abstractmethod
    def Channels(self,
        request: global___QueryChannelsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryChannelsResponse: ...

    @abc.abstractmethod
    def ConnectionChannels(self,
        request: global___QueryConnectionChannelsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryConnectionChannelsResponse: ...

    @abc.abstractmethod
    def ChannelClientState(self,
        request: global___QueryChannelClientStateRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryChannelClientStateResponse: ...

    @abc.abstractmethod
    def ChannelConsensusState(self,
        request: global___QueryChannelConsensusStateRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryChannelConsensusStateResponse: ...

    @abc.abstractmethod
    def PacketCommitment(self,
        request: global___QueryPacketCommitmentRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryPacketCommitmentResponse: ...

    @abc.abstractmethod
    def PacketCommitments(self,
        request: global___QueryPacketCommitmentsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryPacketCommitmentsResponse: ...

    @abc.abstractmethod
    def PacketReceipt(self,
        request: global___QueryPacketReceiptRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryPacketReceiptResponse: ...

    @abc.abstractmethod
    def PacketAcknowledgement(self,
        request: global___QueryPacketAcknowledgementRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryPacketAcknowledgementResponse: ...

    @abc.abstractmethod
    def PacketAcknowledgements(self,
        request: global___QueryPacketAcknowledgementsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryPacketAcknowledgementsResponse: ...

    @abc.abstractmethod
    def UnreceivedPackets(self,
        request: global___QueryUnreceivedPacketsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryUnreceivedPacketsResponse: ...

    @abc.abstractmethod
    def UnreceivedAcks(self,
        request: global___QueryUnreceivedAcksRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryUnreceivedAcksResponse: ...

    @abc.abstractmethod
    def NextSequenceReceive(self,
        request: global___QueryNextSequenceReceiveRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryNextSequenceReceiveResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
