"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Snapshot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    CHUNKS_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    height: builtins.int = ...
    format: builtins.int = ...
    chunks: builtins.int = ...
    hash: builtins.bytes = ...

    @property
    def metadata(self) -> global___Metadata: ...

    def __init__(self,
        *,
        height : builtins.int = ...,
        format : builtins.int = ...,
        chunks : builtins.int = ...,
        hash : builtins.bytes = ...,
        metadata : typing.Optional[global___Metadata] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"metadata",b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chunks",b"chunks",u"format",b"format",u"hash",b"hash",u"height",b"height",u"metadata",b"metadata"]) -> None: ...
global___Snapshot = Snapshot

class Metadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHUNK_HASHES_FIELD_NUMBER: builtins.int

    @property
    def chunk_hashes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...

    def __init__(self,
        *,
        chunk_hashes : typing.Optional[typing.Iterable[builtins.bytes]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chunk_hashes",b"chunk_hashes"]) -> None: ...
global___Metadata = Metadata
