"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Evidence:grpc.UnaryUnaryMultiCallable[
        global___QueryEvidenceRequest,
        global___QueryEvidenceResponse] = ...

    AllEvidence:grpc.UnaryUnaryMultiCallable[
        global___QueryAllEvidenceRequest,
        global___QueryAllEvidenceResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Evidence(self,
        request: global___QueryEvidenceRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryEvidenceResponse: ...

    @abc.abstractmethod
    def AllEvidence(self,
        request: global___QueryAllEvidenceRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryAllEvidenceResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
