"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .tx_pb2 import *
class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ConnectionOpenInit:grpc.UnaryUnaryMultiCallable[
        global___MsgConnectionOpenInit,
        global___MsgConnectionOpenInitResponse] = ...

    ConnectionOpenTry:grpc.UnaryUnaryMultiCallable[
        global___MsgConnectionOpenTry,
        global___MsgConnectionOpenTryResponse] = ...

    ConnectionOpenAck:grpc.UnaryUnaryMultiCallable[
        global___MsgConnectionOpenAck,
        global___MsgConnectionOpenAckResponse] = ...

    ConnectionOpenConfirm:grpc.UnaryUnaryMultiCallable[
        global___MsgConnectionOpenConfirm,
        global___MsgConnectionOpenConfirmResponse] = ...


class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ConnectionOpenInit(self,
        request: global___MsgConnectionOpenInit,
        context: grpc.ServicerContext,
    ) -> global___MsgConnectionOpenInitResponse: ...

    @abc.abstractmethod
    def ConnectionOpenTry(self,
        request: global___MsgConnectionOpenTry,
        context: grpc.ServicerContext,
    ) -> global___MsgConnectionOpenTryResponse: ...

    @abc.abstractmethod
    def ConnectionOpenAck(self,
        request: global___MsgConnectionOpenAck,
        context: grpc.ServicerContext,
    ) -> global___MsgConnectionOpenAckResponse: ...

    @abc.abstractmethod
    def ConnectionOpenConfirm(self,
        request: global___MsgConnectionOpenConfirm,
        context: grpc.ServicerContext,
    ) -> global___MsgConnectionOpenConfirmResponse: ...


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...
