# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oracle/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from oracle.v1 import oracle_pb2 as oracle_dot_v1_dot_oracle__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='oracle/v1/tx.proto',
  package='oracle.v1',
  syntax='proto3',
  serialized_options=b'Z,github.com/bandprotocol/chain/x/oracle/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12oracle/v1/tx.proto\x12\toracle.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x16oracle/v1/oracle.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xc9\x02\n\x0eMsgRequestData\x12>\n\x10oracle_script_id\x18\x01 \x01(\x03\x42$\xe2\xde\x1f\x0eOracleScriptID\xfa\xde\x1f\x0eOracleScriptID\x12\x10\n\x08\x63\x61lldata\x18\x02 \x01(\x0c\x12\x11\n\task_count\x18\x03 \x01(\x04\x12\x11\n\tmin_count\x18\x04 \x01(\x04\x12\x1f\n\tclient_id\x18\x05 \x01(\tB\x0c\xe2\xde\x1f\x08\x43lientID\x12^\n\tfee_limit\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x13\n\x0bprepare_gas\x18\x07 \x01(\x04\x12\x13\n\x0b\x65xecute_gas\x18\x08 \x01(\x04\x12\x0e\n\x06sender\x18\t \x01(\t:\x04\xe8\xa0\x1f\x01\"\x18\n\x16MsgRequestDataResponse\"\x9b\x01\n\rMsgReportData\x12.\n\nrequest_id\x18\x01 \x01(\x03\x42\x1a\xe2\xde\x1f\tRequestID\xfa\xde\x1f\tRequestID\x12/\n\x0braw_reports\x18\x02 \x03(\x0b\x32\x14.oracle.v1.RawReportB\x04\xc8\xde\x1f\x00\x12\x11\n\tvalidator\x18\x03 \x01(\t\x12\x10\n\x08reporter\x18\x04 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x17\n\x15MsgReportDataResponse\"\xdd\x01\n\x13MsgCreateDataSource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nexecutable\x18\x03 \x01(\x0c\x12X\n\x03\x66\x65\x65\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x10\n\x08treasury\x18\x05 \x01(\t\x12\r\n\x05owner\x18\x06 \x01(\t\x12\x0e\n\x06sender\x18\x07 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x1d\n\x1bMsgCreateDataSourceResponse\"\x95\x02\n\x11MsgEditDataSource\x12\x38\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\x03\x42 \xe2\xde\x1f\x0c\x44\x61taSourceID\xfa\xde\x1f\x0c\x44\x61taSourceID\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nexecutable\x18\x04 \x01(\x0c\x12X\n\x03\x66\x65\x65\x18\x05 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x10\n\x08treasury\x18\x06 \x01(\t\x12\r\n\x05owner\x18\x07 \x01(\t\x12\x0e\n\x06sender\x18\x08 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x1b\n\x19MsgEditDataSourceResponse\"\xa9\x01\n\x15MsgCreateOracleScript\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12*\n\x0fsource_code_url\x18\x04 \x01(\tB\x11\xe2\xde\x1f\rSourceCodeURL\x12\x0c\n\x04\x63ode\x18\x05 \x01(\x0c\x12\r\n\x05owner\x18\x06 \x01(\t\x12\x0e\n\x06sender\x18\x07 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x1f\n\x1dMsgCreateOracleScriptResponse\"\xe7\x01\n\x13MsgEditOracleScript\x12>\n\x10oracle_script_id\x18\x01 \x01(\x03\x42$\xe2\xde\x1f\x0eOracleScriptID\xfa\xde\x1f\x0eOracleScriptID\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06schema\x18\x04 \x01(\t\x12*\n\x0fsource_code_url\x18\x05 \x01(\tB\x11\xe2\xde\x1f\rSourceCodeURL\x12\x0c\n\x04\x63ode\x18\x06 \x01(\x0c\x12\r\n\x05owner\x18\x07 \x01(\t\x12\x0e\n\x06sender\x18\x08 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x1d\n\x1bMsgEditOracleScriptResponse\"&\n\x0bMsgActivate\x12\x11\n\tvalidator\x18\x01 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x15\n\x13MsgActivateResponse\";\n\x0eMsgAddReporter\x12\x11\n\tvalidator\x18\x01 \x01(\t\x12\x10\n\x08reporter\x18\x02 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x18\n\x16MsgAddReporterResponse\">\n\x11MsgRemoveReporter\x12\x11\n\tvalidator\x18\x01 \x01(\t\x12\x10\n\x08reporter\x18\x02 \x01(\t:\x04\xe8\xa0\x1f\x01\"\x1b\n\x19MsgRemoveReporterResponse2\xf3\x05\n\x03Msg\x12K\n\x0bRequestData\x12\x19.oracle.v1.MsgRequestData\x1a!.oracle.v1.MsgRequestDataResponse\x12H\n\nReportData\x12\x18.oracle.v1.MsgReportData\x1a .oracle.v1.MsgReportDataResponse\x12Z\n\x10\x43reateDataSource\x12\x1e.oracle.v1.MsgCreateDataSource\x1a&.oracle.v1.MsgCreateDataSourceResponse\x12T\n\x0e\x45\x64itDataSource\x12\x1c.oracle.v1.MsgEditDataSource\x1a$.oracle.v1.MsgEditDataSourceResponse\x12`\n\x12\x43reateOracleScript\x12 .oracle.v1.MsgCreateOracleScript\x1a(.oracle.v1.MsgCreateOracleScriptResponse\x12Z\n\x10\x45\x64itOracleScript\x12\x1e.oracle.v1.MsgEditOracleScript\x1a&.oracle.v1.MsgEditOracleScriptResponse\x12\x42\n\x08\x41\x63tivate\x12\x16.oracle.v1.MsgActivate\x1a\x1e.oracle.v1.MsgActivateResponse\x12K\n\x0b\x41\x64\x64Reporter\x12\x19.oracle.v1.MsgAddReporter\x1a!.oracle.v1.MsgAddReporterResponse\x12T\n\x0eRemoveReporter\x12\x1c.oracle.v1.MsgRemoveReporter\x1a$.oracle.v1.MsgRemoveReporterResponseB.Z,github.com/bandprotocol/chain/x/oracle/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,oracle_dot_v1_dot_oracle__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_MSGREQUESTDATA = _descriptor.Descriptor(
  name='MsgRequestData',
  full_name='oracle.v1.MsgRequestData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='oracle.v1.MsgRequestData.oracle_script_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\016OracleScriptID\372\336\037\016OracleScriptID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calldata', full_name='oracle.v1.MsgRequestData.calldata', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_count', full_name='oracle.v1.MsgRequestData.ask_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='oracle.v1.MsgRequestData.min_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='oracle.v1.MsgRequestData.client_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\010ClientID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_limit', full_name='oracle.v1.MsgRequestData.fee_limit', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prepare_gas', full_name='oracle.v1.MsgRequestData.prepare_gas', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute_gas', full_name='oracle.v1.MsgRequestData.execute_gas', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='oracle.v1.MsgRequestData.sender', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=501,
)


_MSGREQUESTDATARESPONSE = _descriptor.Descriptor(
  name='MsgRequestDataResponse',
  full_name='oracle.v1.MsgRequestDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=503,
  serialized_end=527,
)


_MSGREPORTDATA = _descriptor.Descriptor(
  name='MsgReportData',
  full_name='oracle.v1.MsgReportData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.MsgReportData.request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\tRequestID\372\336\037\tRequestID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_reports', full_name='oracle.v1.MsgReportData.raw_reports', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.MsgReportData.validator', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reporter', full_name='oracle.v1.MsgReportData.reporter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=530,
  serialized_end=685,
)


_MSGREPORTDATARESPONSE = _descriptor.Descriptor(
  name='MsgReportDataResponse',
  full_name='oracle.v1.MsgReportDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=687,
  serialized_end=710,
)


_MSGCREATEDATASOURCE = _descriptor.Descriptor(
  name='MsgCreateDataSource',
  full_name='oracle.v1.MsgCreateDataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='oracle.v1.MsgCreateDataSource.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='oracle.v1.MsgCreateDataSource.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executable', full_name='oracle.v1.MsgCreateDataSource.executable', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='oracle.v1.MsgCreateDataSource.fee', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='treasury', full_name='oracle.v1.MsgCreateDataSource.treasury', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='oracle.v1.MsgCreateDataSource.owner', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='oracle.v1.MsgCreateDataSource.sender', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=713,
  serialized_end=934,
)


_MSGCREATEDATASOURCERESPONSE = _descriptor.Descriptor(
  name='MsgCreateDataSourceResponse',
  full_name='oracle.v1.MsgCreateDataSourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=965,
)


_MSGEDITDATASOURCE = _descriptor.Descriptor(
  name='MsgEditDataSource',
  full_name='oracle.v1.MsgEditDataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_source_id', full_name='oracle.v1.MsgEditDataSource.data_source_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\014DataSourceID\372\336\037\014DataSourceID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='oracle.v1.MsgEditDataSource.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='oracle.v1.MsgEditDataSource.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executable', full_name='oracle.v1.MsgEditDataSource.executable', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='oracle.v1.MsgEditDataSource.fee', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='treasury', full_name='oracle.v1.MsgEditDataSource.treasury', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='oracle.v1.MsgEditDataSource.owner', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='oracle.v1.MsgEditDataSource.sender', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=968,
  serialized_end=1245,
)


_MSGEDITDATASOURCERESPONSE = _descriptor.Descriptor(
  name='MsgEditDataSourceResponse',
  full_name='oracle.v1.MsgEditDataSourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1247,
  serialized_end=1274,
)


_MSGCREATEORACLESCRIPT = _descriptor.Descriptor(
  name='MsgCreateOracleScript',
  full_name='oracle.v1.MsgCreateOracleScript',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='oracle.v1.MsgCreateOracleScript.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='oracle.v1.MsgCreateOracleScript.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='oracle.v1.MsgCreateOracleScript.schema', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_code_url', full_name='oracle.v1.MsgCreateOracleScript.source_code_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\rSourceCodeURL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='oracle.v1.MsgCreateOracleScript.code', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='oracle.v1.MsgCreateOracleScript.owner', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='oracle.v1.MsgCreateOracleScript.sender', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1277,
  serialized_end=1446,
)


_MSGCREATEORACLESCRIPTRESPONSE = _descriptor.Descriptor(
  name='MsgCreateOracleScriptResponse',
  full_name='oracle.v1.MsgCreateOracleScriptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1448,
  serialized_end=1479,
)


_MSGEDITORACLESCRIPT = _descriptor.Descriptor(
  name='MsgEditOracleScript',
  full_name='oracle.v1.MsgEditOracleScript',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='oracle.v1.MsgEditOracleScript.oracle_script_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\016OracleScriptID\372\336\037\016OracleScriptID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='oracle.v1.MsgEditOracleScript.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='oracle.v1.MsgEditOracleScript.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='oracle.v1.MsgEditOracleScript.schema', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_code_url', full_name='oracle.v1.MsgEditOracleScript.source_code_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\rSourceCodeURL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='oracle.v1.MsgEditOracleScript.code', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='oracle.v1.MsgEditOracleScript.owner', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='oracle.v1.MsgEditOracleScript.sender', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1482,
  serialized_end=1713,
)


_MSGEDITORACLESCRIPTRESPONSE = _descriptor.Descriptor(
  name='MsgEditOracleScriptResponse',
  full_name='oracle.v1.MsgEditOracleScriptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1715,
  serialized_end=1744,
)


_MSGACTIVATE = _descriptor.Descriptor(
  name='MsgActivate',
  full_name='oracle.v1.MsgActivate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.MsgActivate.validator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1746,
  serialized_end=1784,
)


_MSGACTIVATERESPONSE = _descriptor.Descriptor(
  name='MsgActivateResponse',
  full_name='oracle.v1.MsgActivateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1786,
  serialized_end=1807,
)


_MSGADDREPORTER = _descriptor.Descriptor(
  name='MsgAddReporter',
  full_name='oracle.v1.MsgAddReporter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.MsgAddReporter.validator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reporter', full_name='oracle.v1.MsgAddReporter.reporter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1809,
  serialized_end=1868,
)


_MSGADDREPORTERRESPONSE = _descriptor.Descriptor(
  name='MsgAddReporterResponse',
  full_name='oracle.v1.MsgAddReporterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1870,
  serialized_end=1894,
)


_MSGREMOVEREPORTER = _descriptor.Descriptor(
  name='MsgRemoveReporter',
  full_name='oracle.v1.MsgRemoveReporter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.MsgRemoveReporter.validator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reporter', full_name='oracle.v1.MsgRemoveReporter.reporter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1896,
  serialized_end=1958,
)


_MSGREMOVEREPORTERRESPONSE = _descriptor.Descriptor(
  name='MsgRemoveReporterResponse',
  full_name='oracle.v1.MsgRemoveReporterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1960,
  serialized_end=1987,
)

_MSGREQUESTDATA.fields_by_name['fee_limit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGREPORTDATA.fields_by_name['raw_reports'].message_type = oracle_dot_v1_dot_oracle__pb2._RAWREPORT
_MSGCREATEDATASOURCE.fields_by_name['fee'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGEDITDATASOURCE.fields_by_name['fee'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['MsgRequestData'] = _MSGREQUESTDATA
DESCRIPTOR.message_types_by_name['MsgRequestDataResponse'] = _MSGREQUESTDATARESPONSE
DESCRIPTOR.message_types_by_name['MsgReportData'] = _MSGREPORTDATA
DESCRIPTOR.message_types_by_name['MsgReportDataResponse'] = _MSGREPORTDATARESPONSE
DESCRIPTOR.message_types_by_name['MsgCreateDataSource'] = _MSGCREATEDATASOURCE
DESCRIPTOR.message_types_by_name['MsgCreateDataSourceResponse'] = _MSGCREATEDATASOURCERESPONSE
DESCRIPTOR.message_types_by_name['MsgEditDataSource'] = _MSGEDITDATASOURCE
DESCRIPTOR.message_types_by_name['MsgEditDataSourceResponse'] = _MSGEDITDATASOURCERESPONSE
DESCRIPTOR.message_types_by_name['MsgCreateOracleScript'] = _MSGCREATEORACLESCRIPT
DESCRIPTOR.message_types_by_name['MsgCreateOracleScriptResponse'] = _MSGCREATEORACLESCRIPTRESPONSE
DESCRIPTOR.message_types_by_name['MsgEditOracleScript'] = _MSGEDITORACLESCRIPT
DESCRIPTOR.message_types_by_name['MsgEditOracleScriptResponse'] = _MSGEDITORACLESCRIPTRESPONSE
DESCRIPTOR.message_types_by_name['MsgActivate'] = _MSGACTIVATE
DESCRIPTOR.message_types_by_name['MsgActivateResponse'] = _MSGACTIVATERESPONSE
DESCRIPTOR.message_types_by_name['MsgAddReporter'] = _MSGADDREPORTER
DESCRIPTOR.message_types_by_name['MsgAddReporterResponse'] = _MSGADDREPORTERRESPONSE
DESCRIPTOR.message_types_by_name['MsgRemoveReporter'] = _MSGREMOVEREPORTER
DESCRIPTOR.message_types_by_name['MsgRemoveReporterResponse'] = _MSGREMOVEREPORTERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgRequestData = _reflection.GeneratedProtocolMessageType('MsgRequestData', (_message.Message,), {
  'DESCRIPTOR' : _MSGREQUESTDATA,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgRequestData)
  })
_sym_db.RegisterMessage(MsgRequestData)

MsgRequestDataResponse = _reflection.GeneratedProtocolMessageType('MsgRequestDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREQUESTDATARESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgRequestDataResponse)
  })
_sym_db.RegisterMessage(MsgRequestDataResponse)

MsgReportData = _reflection.GeneratedProtocolMessageType('MsgReportData', (_message.Message,), {
  'DESCRIPTOR' : _MSGREPORTDATA,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgReportData)
  })
_sym_db.RegisterMessage(MsgReportData)

MsgReportDataResponse = _reflection.GeneratedProtocolMessageType('MsgReportDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREPORTDATARESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgReportDataResponse)
  })
_sym_db.RegisterMessage(MsgReportDataResponse)

MsgCreateDataSource = _reflection.GeneratedProtocolMessageType('MsgCreateDataSource', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEDATASOURCE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgCreateDataSource)
  })
_sym_db.RegisterMessage(MsgCreateDataSource)

MsgCreateDataSourceResponse = _reflection.GeneratedProtocolMessageType('MsgCreateDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEDATASOURCERESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgCreateDataSourceResponse)
  })
_sym_db.RegisterMessage(MsgCreateDataSourceResponse)

MsgEditDataSource = _reflection.GeneratedProtocolMessageType('MsgEditDataSource', (_message.Message,), {
  'DESCRIPTOR' : _MSGEDITDATASOURCE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgEditDataSource)
  })
_sym_db.RegisterMessage(MsgEditDataSource)

MsgEditDataSourceResponse = _reflection.GeneratedProtocolMessageType('MsgEditDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGEDITDATASOURCERESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgEditDataSourceResponse)
  })
_sym_db.RegisterMessage(MsgEditDataSourceResponse)

MsgCreateOracleScript = _reflection.GeneratedProtocolMessageType('MsgCreateOracleScript', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEORACLESCRIPT,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgCreateOracleScript)
  })
_sym_db.RegisterMessage(MsgCreateOracleScript)

MsgCreateOracleScriptResponse = _reflection.GeneratedProtocolMessageType('MsgCreateOracleScriptResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEORACLESCRIPTRESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgCreateOracleScriptResponse)
  })
_sym_db.RegisterMessage(MsgCreateOracleScriptResponse)

MsgEditOracleScript = _reflection.GeneratedProtocolMessageType('MsgEditOracleScript', (_message.Message,), {
  'DESCRIPTOR' : _MSGEDITORACLESCRIPT,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgEditOracleScript)
  })
_sym_db.RegisterMessage(MsgEditOracleScript)

MsgEditOracleScriptResponse = _reflection.GeneratedProtocolMessageType('MsgEditOracleScriptResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGEDITORACLESCRIPTRESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgEditOracleScriptResponse)
  })
_sym_db.RegisterMessage(MsgEditOracleScriptResponse)

MsgActivate = _reflection.GeneratedProtocolMessageType('MsgActivate', (_message.Message,), {
  'DESCRIPTOR' : _MSGACTIVATE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgActivate)
  })
_sym_db.RegisterMessage(MsgActivate)

MsgActivateResponse = _reflection.GeneratedProtocolMessageType('MsgActivateResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGACTIVATERESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgActivateResponse)
  })
_sym_db.RegisterMessage(MsgActivateResponse)

MsgAddReporter = _reflection.GeneratedProtocolMessageType('MsgAddReporter', (_message.Message,), {
  'DESCRIPTOR' : _MSGADDREPORTER,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgAddReporter)
  })
_sym_db.RegisterMessage(MsgAddReporter)

MsgAddReporterResponse = _reflection.GeneratedProtocolMessageType('MsgAddReporterResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGADDREPORTERRESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgAddReporterResponse)
  })
_sym_db.RegisterMessage(MsgAddReporterResponse)

MsgRemoveReporter = _reflection.GeneratedProtocolMessageType('MsgRemoveReporter', (_message.Message,), {
  'DESCRIPTOR' : _MSGREMOVEREPORTER,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgRemoveReporter)
  })
_sym_db.RegisterMessage(MsgRemoveReporter)

MsgRemoveReporterResponse = _reflection.GeneratedProtocolMessageType('MsgRemoveReporterResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREMOVEREPORTERRESPONSE,
  '__module__' : 'oracle.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.MsgRemoveReporterResponse)
  })
_sym_db.RegisterMessage(MsgRemoveReporterResponse)


DESCRIPTOR._options = None
_MSGREQUESTDATA.fields_by_name['oracle_script_id']._options = None
_MSGREQUESTDATA.fields_by_name['client_id']._options = None
_MSGREQUESTDATA.fields_by_name['fee_limit']._options = None
_MSGREQUESTDATA._options = None
_MSGREPORTDATA.fields_by_name['request_id']._options = None
_MSGREPORTDATA.fields_by_name['raw_reports']._options = None
_MSGREPORTDATA._options = None
_MSGCREATEDATASOURCE.fields_by_name['fee']._options = None
_MSGCREATEDATASOURCE._options = None
_MSGEDITDATASOURCE.fields_by_name['data_source_id']._options = None
_MSGEDITDATASOURCE.fields_by_name['fee']._options = None
_MSGEDITDATASOURCE._options = None
_MSGCREATEORACLESCRIPT.fields_by_name['source_code_url']._options = None
_MSGCREATEORACLESCRIPT._options = None
_MSGEDITORACLESCRIPT.fields_by_name['oracle_script_id']._options = None
_MSGEDITORACLESCRIPT.fields_by_name['source_code_url']._options = None
_MSGEDITORACLESCRIPT._options = None
_MSGACTIVATE._options = None
_MSGADDREPORTER._options = None
_MSGREMOVEREPORTER._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='oracle.v1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1990,
  serialized_end=2745,
  methods=[
  _descriptor.MethodDescriptor(
    name='RequestData',
    full_name='oracle.v1.Msg.RequestData',
    index=0,
    containing_service=None,
    input_type=_MSGREQUESTDATA,
    output_type=_MSGREQUESTDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReportData',
    full_name='oracle.v1.Msg.ReportData',
    index=1,
    containing_service=None,
    input_type=_MSGREPORTDATA,
    output_type=_MSGREPORTDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataSource',
    full_name='oracle.v1.Msg.CreateDataSource',
    index=2,
    containing_service=None,
    input_type=_MSGCREATEDATASOURCE,
    output_type=_MSGCREATEDATASOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditDataSource',
    full_name='oracle.v1.Msg.EditDataSource',
    index=3,
    containing_service=None,
    input_type=_MSGEDITDATASOURCE,
    output_type=_MSGEDITDATASOURCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateOracleScript',
    full_name='oracle.v1.Msg.CreateOracleScript',
    index=4,
    containing_service=None,
    input_type=_MSGCREATEORACLESCRIPT,
    output_type=_MSGCREATEORACLESCRIPTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EditOracleScript',
    full_name='oracle.v1.Msg.EditOracleScript',
    index=5,
    containing_service=None,
    input_type=_MSGEDITORACLESCRIPT,
    output_type=_MSGEDITORACLESCRIPTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Activate',
    full_name='oracle.v1.Msg.Activate',
    index=6,
    containing_service=None,
    input_type=_MSGACTIVATE,
    output_type=_MSGACTIVATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddReporter',
    full_name='oracle.v1.Msg.AddReporter',
    index=7,
    containing_service=None,
    input_type=_MSGADDREPORTER,
    output_type=_MSGADDREPORTERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveReporter',
    full_name='oracle.v1.Msg.RemoveReporter',
    index=8,
    containing_service=None,
    input_type=_MSGREMOVEREPORTER,
    output_type=_MSGREMOVEREPORTERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)
