"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import cosmos.gov.v1beta1.gov_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MsgSubmitProposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONTENT_FIELD_NUMBER: builtins.int
    INITIAL_DEPOSIT_FIELD_NUMBER: builtins.int
    PROPOSER_FIELD_NUMBER: builtins.int
    proposer: typing.Text = ...

    @property
    def content(self) -> google.protobuf.any_pb2.Any: ...

    @property
    def initial_deposit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        content : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        initial_deposit : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        proposer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"content",b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"content",b"content",u"initial_deposit",b"initial_deposit",u"proposer",b"proposer"]) -> None: ...
global___MsgSubmitProposal = MsgSubmitProposal

class MsgSubmitProposalResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"proposal_id",b"proposal_id"]) -> None: ...
global___MsgSubmitProposalResponse = MsgSubmitProposalResponse

class MsgVote(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    OPTION_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...
    voter: typing.Text = ...
    option: cosmos.gov.v1beta1.gov_pb2.VoteOption.V = ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        voter : typing.Text = ...,
        option : cosmos.gov.v1beta1.gov_pb2.VoteOption.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"option",b"option",u"proposal_id",b"proposal_id",u"voter",b"voter"]) -> None: ...
global___MsgVote = MsgVote

class MsgVoteResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgVoteResponse = MsgVoteResponse

class MsgDeposit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...
    depositor: typing.Text = ...

    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        depositor : typing.Text = ...,
        amount : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"depositor",b"depositor",u"proposal_id",b"proposal_id"]) -> None: ...
global___MsgDeposit = MsgDeposit

class MsgDepositResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgDepositResponse = MsgDepositResponse
