"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Balance:grpc.UnaryUnaryMultiCallable[
        global___QueryBalanceRequest,
        global___QueryBalanceResponse] = ...

    AllBalances:grpc.UnaryUnaryMultiCallable[
        global___QueryAllBalancesRequest,
        global___QueryAllBalancesResponse] = ...

    TotalSupply:grpc.UnaryUnaryMultiCallable[
        global___QueryTotalSupplyRequest,
        global___QueryTotalSupplyResponse] = ...

    SupplyOf:grpc.UnaryUnaryMultiCallable[
        global___QuerySupplyOfRequest,
        global___QuerySupplyOfResponse] = ...

    Params:grpc.UnaryUnaryMultiCallable[
        global___QueryParamsRequest,
        global___QueryParamsResponse] = ...

    DenomMetadata:grpc.UnaryUnaryMultiCallable[
        global___QueryDenomMetadataRequest,
        global___QueryDenomMetadataResponse] = ...

    DenomsMetadata:grpc.UnaryUnaryMultiCallable[
        global___QueryDenomsMetadataRequest,
        global___QueryDenomsMetadataResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Balance(self,
        request: global___QueryBalanceRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryBalanceResponse: ...

    @abc.abstractmethod
    def AllBalances(self,
        request: global___QueryAllBalancesRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryAllBalancesResponse: ...

    @abc.abstractmethod
    def TotalSupply(self,
        request: global___QueryTotalSupplyRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryTotalSupplyResponse: ...

    @abc.abstractmethod
    def SupplyOf(self,
        request: global___QuerySupplyOfRequest,
        context: grpc.ServicerContext,
    ) -> global___QuerySupplyOfResponse: ...

    @abc.abstractmethod
    def Params(self,
        request: global___QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryParamsResponse: ...

    @abc.abstractmethod
    def DenomMetadata(self,
        request: global___QueryDenomMetadataRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDenomMetadataResponse: ...

    @abc.abstractmethod
    def DenomsMetadata(self,
        request: global___QueryDenomsMetadataRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDenomsMetadataResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
