"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ValidatorSigningInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    START_HEIGHT_FIELD_NUMBER: builtins.int
    INDEX_OFFSET_FIELD_NUMBER: builtins.int
    JAILED_UNTIL_FIELD_NUMBER: builtins.int
    TOMBSTONED_FIELD_NUMBER: builtins.int
    MISSED_BLOCKS_COUNTER_FIELD_NUMBER: builtins.int
    address: typing.Text = ...
    start_height: builtins.int = ...
    index_offset: builtins.int = ...
    tombstoned: builtins.bool = ...
    missed_blocks_counter: builtins.int = ...

    @property
    def jailed_until(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        start_height : builtins.int = ...,
        index_offset : builtins.int = ...,
        jailed_until : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        tombstoned : builtins.bool = ...,
        missed_blocks_counter : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"jailed_until",b"jailed_until"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"address",b"address",u"index_offset",b"index_offset",u"jailed_until",b"jailed_until",u"missed_blocks_counter",b"missed_blocks_counter",u"start_height",b"start_height",u"tombstoned",b"tombstoned"]) -> None: ...
global___ValidatorSigningInfo = ValidatorSigningInfo

class Params(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SIGNED_BLOCKS_WINDOW_FIELD_NUMBER: builtins.int
    MIN_SIGNED_PER_WINDOW_FIELD_NUMBER: builtins.int
    DOWNTIME_JAIL_DURATION_FIELD_NUMBER: builtins.int
    SLASH_FRACTION_DOUBLE_SIGN_FIELD_NUMBER: builtins.int
    SLASH_FRACTION_DOWNTIME_FIELD_NUMBER: builtins.int
    signed_blocks_window: builtins.int = ...
    min_signed_per_window: builtins.bytes = ...
    slash_fraction_double_sign: builtins.bytes = ...
    slash_fraction_downtime: builtins.bytes = ...

    @property
    def downtime_jail_duration(self) -> google.protobuf.duration_pb2.Duration: ...

    def __init__(self,
        *,
        signed_blocks_window : builtins.int = ...,
        min_signed_per_window : builtins.bytes = ...,
        downtime_jail_duration : typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        slash_fraction_double_sign : builtins.bytes = ...,
        slash_fraction_downtime : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"downtime_jail_duration",b"downtime_jail_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"downtime_jail_duration",b"downtime_jail_duration",u"min_signed_per_window",b"min_signed_per_window",u"signed_blocks_window",b"signed_blocks_window",u"slash_fraction_double_sign",b"slash_fraction_double_sign",u"slash_fraction_downtime",b"slash_fraction_downtime"]) -> None: ...
global___Params = Params
