"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import oracle.v1.oracle_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MsgRequestData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ORACLE_SCRIPT_ID_FIELD_NUMBER: builtins.int
    CALLDATA_FIELD_NUMBER: builtins.int
    ASK_COUNT_FIELD_NUMBER: builtins.int
    MIN_COUNT_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    FEE_LIMIT_FIELD_NUMBER: builtins.int
    PREPARE_GAS_FIELD_NUMBER: builtins.int
    EXECUTE_GAS_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    oracle_script_id: builtins.int = ...
    calldata: builtins.bytes = ...
    ask_count: builtins.int = ...
    min_count: builtins.int = ...
    client_id: typing.Text = ...
    prepare_gas: builtins.int = ...
    execute_gas: builtins.int = ...
    sender: typing.Text = ...

    @property
    def fee_limit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        oracle_script_id : builtins.int = ...,
        calldata : builtins.bytes = ...,
        ask_count : builtins.int = ...,
        min_count : builtins.int = ...,
        client_id : typing.Text = ...,
        fee_limit : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        prepare_gas : builtins.int = ...,
        execute_gas : builtins.int = ...,
        sender : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"ask_count",b"ask_count",u"calldata",b"calldata",u"client_id",b"client_id",u"execute_gas",b"execute_gas",u"fee_limit",b"fee_limit",u"min_count",b"min_count",u"oracle_script_id",b"oracle_script_id",u"prepare_gas",b"prepare_gas",u"sender",b"sender"]) -> None: ...
global___MsgRequestData = MsgRequestData

class MsgRequestDataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgRequestDataResponse = MsgRequestDataResponse

class MsgReportData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_ID_FIELD_NUMBER: builtins.int
    RAW_REPORTS_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    REPORTER_FIELD_NUMBER: builtins.int
    request_id: builtins.int = ...
    validator: typing.Text = ...
    reporter: typing.Text = ...

    @property
    def raw_reports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[oracle.v1.oracle_pb2.RawReport]: ...

    def __init__(self,
        *,
        request_id : builtins.int = ...,
        raw_reports : typing.Optional[typing.Iterable[oracle.v1.oracle_pb2.RawReport]] = ...,
        validator : typing.Text = ...,
        reporter : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"raw_reports",b"raw_reports",u"reporter",b"reporter",u"request_id",b"request_id",u"validator",b"validator"]) -> None: ...
global___MsgReportData = MsgReportData

class MsgReportDataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgReportDataResponse = MsgReportDataResponse

class MsgCreateDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXECUTABLE_FIELD_NUMBER: builtins.int
    FEE_FIELD_NUMBER: builtins.int
    TREASURY_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    description: typing.Text = ...
    executable: builtins.bytes = ...
    treasury: typing.Text = ...
    owner: typing.Text = ...
    sender: typing.Text = ...

    @property
    def fee(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        name : typing.Text = ...,
        description : typing.Text = ...,
        executable : builtins.bytes = ...,
        fee : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        treasury : typing.Text = ...,
        owner : typing.Text = ...,
        sender : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"description",b"description",u"executable",b"executable",u"fee",b"fee",u"name",b"name",u"owner",b"owner",u"sender",b"sender",u"treasury",b"treasury"]) -> None: ...
global___MsgCreateDataSource = MsgCreateDataSource

class MsgCreateDataSourceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgCreateDataSourceResponse = MsgCreateDataSourceResponse

class MsgEditDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXECUTABLE_FIELD_NUMBER: builtins.int
    FEE_FIELD_NUMBER: builtins.int
    TREASURY_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    data_source_id: builtins.int = ...
    name: typing.Text = ...
    description: typing.Text = ...
    executable: builtins.bytes = ...
    treasury: typing.Text = ...
    owner: typing.Text = ...
    sender: typing.Text = ...

    @property
    def fee(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        data_source_id : builtins.int = ...,
        name : typing.Text = ...,
        description : typing.Text = ...,
        executable : builtins.bytes = ...,
        fee : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        treasury : typing.Text = ...,
        owner : typing.Text = ...,
        sender : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data_source_id",b"data_source_id",u"description",b"description",u"executable",b"executable",u"fee",b"fee",u"name",b"name",u"owner",b"owner",u"sender",b"sender",u"treasury",b"treasury"]) -> None: ...
global___MsgEditDataSource = MsgEditDataSource

class MsgEditDataSourceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgEditDataSourceResponse = MsgEditDataSourceResponse

class MsgCreateOracleScript(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    SOURCE_CODE_URL_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    description: typing.Text = ...
    schema: typing.Text = ...
    source_code_url: typing.Text = ...
    code: builtins.bytes = ...
    owner: typing.Text = ...
    sender: typing.Text = ...

    def __init__(self,
        *,
        name : typing.Text = ...,
        description : typing.Text = ...,
        schema : typing.Text = ...,
        source_code_url : typing.Text = ...,
        code : builtins.bytes = ...,
        owner : typing.Text = ...,
        sender : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"code",b"code",u"description",b"description",u"name",b"name",u"owner",b"owner",u"schema",b"schema",u"sender",b"sender",u"source_code_url",b"source_code_url"]) -> None: ...
global___MsgCreateOracleScript = MsgCreateOracleScript

class MsgCreateOracleScriptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgCreateOracleScriptResponse = MsgCreateOracleScriptResponse

class MsgEditOracleScript(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ORACLE_SCRIPT_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    SOURCE_CODE_URL_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    oracle_script_id: builtins.int = ...
    name: typing.Text = ...
    description: typing.Text = ...
    schema: typing.Text = ...
    source_code_url: typing.Text = ...
    code: builtins.bytes = ...
    owner: typing.Text = ...
    sender: typing.Text = ...

    def __init__(self,
        *,
        oracle_script_id : builtins.int = ...,
        name : typing.Text = ...,
        description : typing.Text = ...,
        schema : typing.Text = ...,
        source_code_url : typing.Text = ...,
        code : builtins.bytes = ...,
        owner : typing.Text = ...,
        sender : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"code",b"code",u"description",b"description",u"name",b"name",u"oracle_script_id",b"oracle_script_id",u"owner",b"owner",u"schema",b"schema",u"sender",b"sender",u"source_code_url",b"source_code_url"]) -> None: ...
global___MsgEditOracleScript = MsgEditOracleScript

class MsgEditOracleScriptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgEditOracleScriptResponse = MsgEditOracleScriptResponse

class MsgActivate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_FIELD_NUMBER: builtins.int
    validator: typing.Text = ...

    def __init__(self,
        *,
        validator : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"validator",b"validator"]) -> None: ...
global___MsgActivate = MsgActivate

class MsgActivateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgActivateResponse = MsgActivateResponse

class MsgAddReporter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_FIELD_NUMBER: builtins.int
    REPORTER_FIELD_NUMBER: builtins.int
    validator: typing.Text = ...
    reporter: typing.Text = ...

    def __init__(self,
        *,
        validator : typing.Text = ...,
        reporter : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"reporter",b"reporter",u"validator",b"validator"]) -> None: ...
global___MsgAddReporter = MsgAddReporter

class MsgAddReporterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgAddReporterResponse = MsgAddReporterResponse

class MsgRemoveReporter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_FIELD_NUMBER: builtins.int
    REPORTER_FIELD_NUMBER: builtins.int
    validator: typing.Text = ...
    reporter: typing.Text = ...

    def __init__(self,
        *,
        validator : typing.Text = ...,
        reporter : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"reporter",b"reporter",u"validator",b"validator"]) -> None: ...
global___MsgRemoveReporter = MsgRemoveReporter

class MsgRemoveReporterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgRemoveReporterResponse = MsgRemoveReporterResponse
