"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    COUNT_TOTAL_FIELD_NUMBER: builtins.int
    key: builtins.bytes = ...
    offset: builtins.int = ...
    limit: builtins.int = ...
    count_total: builtins.bool = ...

    def __init__(self,
        *,
        key : builtins.bytes = ...,
        offset : builtins.int = ...,
        limit : builtins.int = ...,
        count_total : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"count_total",b"count_total",u"key",b"key",u"limit",b"limit",u"offset",b"offset"]) -> None: ...
global___PageRequest = PageRequest

class PageResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NEXT_KEY_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    next_key: builtins.bytes = ...
    total: builtins.int = ...

    def __init__(self,
        *,
        next_key : builtins.bytes = ...,
        total : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"next_key",b"next_key",u"total",b"total"]) -> None: ...
global___PageResponse = PageResponse
