# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oracle/v1/oracle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='oracle/v1/oracle.proto',
  package='oracle.v1',
  syntax='proto3',
  serialized_options=b'Z,github.com/bandprotocol/chain/x/oracle/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16oracle/v1/oracle.proto\x12\toracle.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xc2\x01\n\nDataSource\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x10\n\x08treasury\x18\x05 \x01(\t\x12X\n\x03\x66\x65\x65\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x04\xe8\xa0\x1f\x01\"\x94\x01\n\x0cOracleScript\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x0e\n\x06schema\x18\x05 \x01(\t\x12*\n\x0fsource_code_url\x18\x06 \x01(\tB\x11\xe2\xde\x1f\rSourceCodeURL:\x04\xe8\xa0\x1f\x01\"\x91\x01\n\nRawRequest\x12\x31\n\x0b\x65xternal_id\x18\x01 \x01(\x03\x42\x1c\xe2\xde\x1f\nExternalID\xfa\xde\x1f\nExternalID\x12\x38\n\x0e\x64\x61ta_source_id\x18\x02 \x01(\x03\x42 \xe2\xde\x1f\x0c\x44\x61taSourceID\xfa\xde\x1f\x0c\x44\x61taSourceID\x12\x10\n\x08\x63\x61lldata\x18\x03 \x01(\x0c:\x04\xe8\xa0\x1f\x01\"e\n\tRawReport\x12\x31\n\x0b\x65xternal_id\x18\x01 \x01(\x03\x42\x1c\xe2\xde\x1f\nExternalID\xfa\xde\x1f\nExternalID\x12\x11\n\texit_code\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c:\x04\xe8\xa0\x1f\x01\"\xe5\x02\n\x07Request\x12>\n\x10oracle_script_id\x18\x01 \x01(\x03\x42$\xe2\xde\x1f\x0eOracleScriptID\xfa\xde\x1f\x0eOracleScriptID\x12\x10\n\x08\x63\x61lldata\x18\x02 \x01(\x0c\x12\x1c\n\x14requested_validators\x18\x03 \x03(\t\x12\x11\n\tmin_count\x18\x04 \x01(\x04\x12\x16\n\x0erequest_height\x18\x05 \x01(\x03\x12\x14\n\x0crequest_time\x18\x06 \x01(\x04\x12\x1f\n\tclient_id\x18\x07 \x01(\tB\x0c\xe2\xde\x1f\x08\x43lientID\x12\x31\n\x0craw_requests\x18\x08 \x03(\x0b\x32\x15.oracle.v1.RawRequestB\x04\xc8\xde\x1f\x00\x12:\n\x0bibc_channel\x18\t \x01(\x0b\x32\x15.oracle.v1.IBCChannelB\x0e\xe2\xde\x1f\nIBCChannel\x12\x13\n\x0b\x65xecute_gas\x18\n \x01(\x04:\x04\xe8\xa0\x1f\x01\"m\n\x06Report\x12\x11\n\tvalidator\x18\x01 \x01(\t\x12\x19\n\x11in_before_resolve\x18\x02 \x01(\x08\x12/\n\x0braw_reports\x18\x03 \x03(\x0b\x32\x14.oracle.v1.RawReportB\x04\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\"\xd7\x02\n\x17OracleRequestPacketData\x12\x1f\n\tclient_id\x18\x01 \x01(\tB\x0c\xe2\xde\x1f\x08\x43lientID\x12>\n\x10oracle_script_id\x18\x02 \x01(\x03\x42$\xe2\xde\x1f\x0eOracleScriptID\xfa\xde\x1f\x0eOracleScriptID\x12\x10\n\x08\x63\x61lldata\x18\x03 \x01(\x0c\x12\x11\n\task_count\x18\x04 \x01(\x04\x12\x11\n\tmin_count\x18\x05 \x01(\x04\x12^\n\tfee_limit\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x13\n\x0brequest_key\x18\x07 \x01(\t\x12\x13\n\x0bprepare_gas\x18\x08 \x01(\x04\x12\x13\n\x0b\x65xecute_gas\x18\t \x01(\x04:\x04\xe8\xa0\x1f\x01\"Z\n\"OracleRequestPacketAcknowledgement\x12.\n\nrequest_id\x18\x01 \x01(\x03\x42\x1a\xe2\xde\x1f\tRequestID\xfa\xde\x1f\tRequestID:\x04\xe8\xa0\x1f\x01\"\xf2\x01\n\x18OracleResponsePacketData\x12\x1f\n\tclient_id\x18\x01 \x01(\tB\x0c\xe2\xde\x1f\x08\x43lientID\x12.\n\nrequest_id\x18\x02 \x01(\x03\x42\x1a\xe2\xde\x1f\tRequestID\xfa\xde\x1f\tRequestID\x12\x11\n\tans_count\x18\x03 \x01(\x04\x12\x14\n\x0crequest_time\x18\x04 \x01(\x03\x12\x14\n\x0cresolve_time\x18\x05 \x01(\x03\x12\x30\n\x0eresolve_status\x18\x06 \x01(\x0e\x32\x18.oracle.v1.ResolveStatus\x12\x0e\n\x06result\x18\x07 \x01(\x0c:\x04\xe8\xa0\x1f\x01\"\xd8\x02\n\x06Result\x12\x1f\n\tclient_id\x18\x01 \x01(\tB\x0c\xe2\xde\x1f\x08\x43lientID\x12>\n\x10oracle_script_id\x18\x02 \x01(\x03\x42$\xe2\xde\x1f\x0eOracleScriptID\xfa\xde\x1f\x0eOracleScriptID\x12\x10\n\x08\x63\x61lldata\x18\x03 \x01(\x0c\x12\x11\n\task_count\x18\x04 \x01(\x04\x12\x11\n\tmin_count\x18\x05 \x01(\x04\x12.\n\nrequest_id\x18\x06 \x01(\x03\x42\x1a\xe2\xde\x1f\tRequestID\xfa\xde\x1f\tRequestID\x12\x11\n\tans_count\x18\x07 \x01(\x04\x12\x14\n\x0crequest_time\x18\x08 \x01(\x03\x12\x14\n\x0cresolve_time\x18\t \x01(\x03\x12\x30\n\x0eresolve_status\x18\n \x01(\x0e\x32\x18.oracle.v1.ResolveStatus\x12\x0e\n\x06result\x18\x0b \x01(\x0c:\x04\xe8\xa0\x1f\x01\"_\n\x0fValidatorStatus\x12\x11\n\tis_active\x18\x01 \x01(\x08\x12\x33\n\x05since\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01:\x04\xe8\xa0\x1f\x01\"1\n\x0f\x41\x63tiveValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05power\x18\x02 \x01(\x04\"\xb8\x02\n\x06Params\x12\x1d\n\x15max_raw_request_count\x18\x01 \x01(\x04\x12\x15\n\rmax_ask_count\x18\x02 \x01(\x04\x12\x1e\n\x16\x65xpiration_block_count\x18\x03 \x01(\x04\x12\x16\n\x0e\x62\x61se_owasm_gas\x18\x04 \x01(\x04\x12!\n\x19per_validator_request_gas\x18\x05 \x01(\x04\x12\x1a\n\x12sampling_try_count\x18\x06 \x01(\x04\x12 \n\x18oracle_reward_percentage\x18\x07 \x01(\x04\x12!\n\x19inactive_penalty_duration\x18\x08 \x01(\x04\x12\x32\n\x13ibc_request_enabled\x18\t \x01(\x08\x42\x15\xe2\xde\x1f\x11IBCRequestEnabled:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"/\n\x12PendingResolveList\x12\x13\n\x0brequest_ids\x18\x01 \x03(\x03:\x04\xe8\xa0\x1f\x01\"7\n\nIBCChannel\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t:\x04\xe8\xa0\x1f\x01\"C\n\x15ReportersPerValidator\x12\x11\n\tvalidator\x18\x01 \x01(\t\x12\x17\n\treporters\x18\x02 \x03(\tB\x04\xc8\xde\x1f\x00\"\xb0\x01\n\x13RequestVerification\x12\x1d\n\x08\x63hain_id\x18\x01 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainID\x12\x11\n\tvalidator\x18\x02 \x01(\t\x12.\n\nrequest_id\x18\x03 \x01(\x03\x42\x1a\xe2\xde\x1f\tRequestID\xfa\xde\x1f\tRequestID\x12\x31\n\x0b\x65xternal_id\x18\x04 \x01(\x03\x42\x1c\xe2\xde\x1f\nExternalID\xfa\xde\x1f\nExternalID:\x04\xe8\xa0\x1f\x01\"\x83\x01\n\x0bPriceResult\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x12\n\nmultiplier\x18\x02 \x01(\x04\x12\n\n\x02px\x18\x03 \x01(\x04\x12.\n\nrequest_id\x18\x04 \x01(\x03\x42\x1a\xe2\xde\x1f\tRequestID\xfa\xde\x1f\tRequestID\x12\x14\n\x0cresolve_time\x18\x05 \x01(\x03*\xfb\x01\n\rResolveStatus\x12<\n\x1fRESOLVE_STATUS_OPEN_UNSPECIFIED\x10\x00\x1a\x17\x8a\x9d \x13RESOLVE_STATUS_OPEN\x12\x36\n\x16RESOLVE_STATUS_SUCCESS\x10\x01\x1a\x1a\x8a\x9d \x16RESOLVE_STATUS_SUCCESS\x12\x36\n\x16RESOLVE_STATUS_FAILURE\x10\x02\x1a\x1a\x8a\x9d \x16RESOLVE_STATUS_FAILURE\x12\x36\n\x16RESOLVE_STATUS_EXPIRED\x10\x03\x1a\x1a\x8a\x9d \x16RESOLVE_STATUS_EXPIRED\x1a\x04\x88\xa3\x1e\x00\x42.Z,github.com/bandprotocol/chain/x/oracle/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])

_RESOLVESTATUS = _descriptor.EnumDescriptor(
  name='ResolveStatus',
  full_name='oracle.v1.ResolveStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESOLVE_STATUS_OPEN_UNSPECIFIED', index=0, number=0,
      serialized_options=b'\212\235 \023RESOLVE_STATUS_OPEN',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOLVE_STATUS_SUCCESS', index=1, number=1,
      serialized_options=b'\212\235 \026RESOLVE_STATUS_SUCCESS',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOLVE_STATUS_FAILURE', index=2, number=2,
      serialized_options=b'\212\235 \026RESOLVE_STATUS_FAILURE',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOLVE_STATUS_EXPIRED', index=3, number=3,
      serialized_options=b'\212\235 \026RESOLVE_STATUS_EXPIRED',
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\210\243\036\000',
  serialized_start=3203,
  serialized_end=3454,
)
_sym_db.RegisterEnumDescriptor(_RESOLVESTATUS)

ResolveStatus = enum_type_wrapper.EnumTypeWrapper(_RESOLVESTATUS)
RESOLVE_STATUS_OPEN_UNSPECIFIED = 0
RESOLVE_STATUS_SUCCESS = 1
RESOLVE_STATUS_FAILURE = 2
RESOLVE_STATUS_EXPIRED = 3



_DATASOURCE = _descriptor.Descriptor(
  name='DataSource',
  full_name='oracle.v1.DataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='oracle.v1.DataSource.owner', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='oracle.v1.DataSource.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='oracle.v1.DataSource.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename', full_name='oracle.v1.DataSource.filename', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='treasury', full_name='oracle.v1.DataSource.treasury', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='oracle.v1.DataSource.fee', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=346,
)


_ORACLESCRIPT = _descriptor.Descriptor(
  name='OracleScript',
  full_name='oracle.v1.OracleScript',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='oracle.v1.OracleScript.owner', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='oracle.v1.OracleScript.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='oracle.v1.OracleScript.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename', full_name='oracle.v1.OracleScript.filename', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='oracle.v1.OracleScript.schema', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_code_url', full_name='oracle.v1.OracleScript.source_code_url', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\rSourceCodeURL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=497,
)


_RAWREQUEST = _descriptor.Descriptor(
  name='RawRequest',
  full_name='oracle.v1.RawRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_id', full_name='oracle.v1.RawRequest.external_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\nExternalID\372\336\037\nExternalID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_id', full_name='oracle.v1.RawRequest.data_source_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\014DataSourceID\372\336\037\014DataSourceID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calldata', full_name='oracle.v1.RawRequest.calldata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=645,
)


_RAWREPORT = _descriptor.Descriptor(
  name='RawReport',
  full_name='oracle.v1.RawReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_id', full_name='oracle.v1.RawReport.external_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\nExternalID\372\336\037\nExternalID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exit_code', full_name='oracle.v1.RawReport.exit_code', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='oracle.v1.RawReport.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=748,
)


_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='oracle.v1.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='oracle.v1.Request.oracle_script_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\016OracleScriptID\372\336\037\016OracleScriptID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calldata', full_name='oracle.v1.Request.calldata', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requested_validators', full_name='oracle.v1.Request.requested_validators', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='oracle.v1.Request.min_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_height', full_name='oracle.v1.Request.request_height', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_time', full_name='oracle.v1.Request.request_time', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='oracle.v1.Request.client_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\010ClientID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_requests', full_name='oracle.v1.Request.raw_requests', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_channel', full_name='oracle.v1.Request.ibc_channel', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\nIBCChannel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute_gas', full_name='oracle.v1.Request.execute_gas', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=1108,
)


_REPORT = _descriptor.Descriptor(
  name='Report',
  full_name='oracle.v1.Report',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.Report.validator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_before_resolve', full_name='oracle.v1.Report.in_before_resolve', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_reports', full_name='oracle.v1.Report.raw_reports', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1110,
  serialized_end=1219,
)


_ORACLEREQUESTPACKETDATA = _descriptor.Descriptor(
  name='OracleRequestPacketData',
  full_name='oracle.v1.OracleRequestPacketData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='oracle.v1.OracleRequestPacketData.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\010ClientID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='oracle.v1.OracleRequestPacketData.oracle_script_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\016OracleScriptID\372\336\037\016OracleScriptID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calldata', full_name='oracle.v1.OracleRequestPacketData.calldata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_count', full_name='oracle.v1.OracleRequestPacketData.ask_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='oracle.v1.OracleRequestPacketData.min_count', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_limit', full_name='oracle.v1.OracleRequestPacketData.fee_limit', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_key', full_name='oracle.v1.OracleRequestPacketData.request_key', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prepare_gas', full_name='oracle.v1.OracleRequestPacketData.prepare_gas', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute_gas', full_name='oracle.v1.OracleRequestPacketData.execute_gas', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1222,
  serialized_end=1565,
)


_ORACLEREQUESTPACKETACKNOWLEDGEMENT = _descriptor.Descriptor(
  name='OracleRequestPacketAcknowledgement',
  full_name='oracle.v1.OracleRequestPacketAcknowledgement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.OracleRequestPacketAcknowledgement.request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\tRequestID\372\336\037\tRequestID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1567,
  serialized_end=1657,
)


_ORACLERESPONSEPACKETDATA = _descriptor.Descriptor(
  name='OracleResponsePacketData',
  full_name='oracle.v1.OracleResponsePacketData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='oracle.v1.OracleResponsePacketData.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\010ClientID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.OracleResponsePacketData.request_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\tRequestID\372\336\037\tRequestID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ans_count', full_name='oracle.v1.OracleResponsePacketData.ans_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_time', full_name='oracle.v1.OracleResponsePacketData.request_time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_time', full_name='oracle.v1.OracleResponsePacketData.resolve_time', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_status', full_name='oracle.v1.OracleResponsePacketData.resolve_status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='oracle.v1.OracleResponsePacketData.result', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1660,
  serialized_end=1902,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='oracle.v1.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='oracle.v1.Result.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\010ClientID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_script_id', full_name='oracle.v1.Result.oracle_script_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\016OracleScriptID\372\336\037\016OracleScriptID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calldata', full_name='oracle.v1.Result.calldata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ask_count', full_name='oracle.v1.Result.ask_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_count', full_name='oracle.v1.Result.min_count', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.Result.request_id', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\tRequestID\372\336\037\tRequestID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ans_count', full_name='oracle.v1.Result.ans_count', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_time', full_name='oracle.v1.Result.request_time', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_time', full_name='oracle.v1.Result.resolve_time', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_status', full_name='oracle.v1.Result.resolve_status', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='oracle.v1.Result.result', index=10,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1905,
  serialized_end=2249,
)


_VALIDATORSTATUS = _descriptor.Descriptor(
  name='ValidatorStatus',
  full_name='oracle.v1.ValidatorStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_active', full_name='oracle.v1.ValidatorStatus.is_active', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='since', full_name='oracle.v1.ValidatorStatus.since', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\220\337\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2251,
  serialized_end=2346,
)


_ACTIVEVALIDATOR = _descriptor.Descriptor(
  name='ActiveValidator',
  full_name='oracle.v1.ActiveValidator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='oracle.v1.ActiveValidator.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='power', full_name='oracle.v1.ActiveValidator.power', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2348,
  serialized_end=2397,
)


_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='oracle.v1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_raw_request_count', full_name='oracle.v1.Params.max_raw_request_count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_ask_count', full_name='oracle.v1.Params.max_ask_count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration_block_count', full_name='oracle.v1.Params.expiration_block_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_owasm_gas', full_name='oracle.v1.Params.base_owasm_gas', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='per_validator_request_gas', full_name='oracle.v1.Params.per_validator_request_gas', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling_try_count', full_name='oracle.v1.Params.sampling_try_count', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_reward_percentage', full_name='oracle.v1.Params.oracle_reward_percentage', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inactive_penalty_duration', full_name='oracle.v1.Params.inactive_penalty_duration', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ibc_request_enabled', full_name='oracle.v1.Params.ibc_request_enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\021IBCRequestEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001\230\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2400,
  serialized_end=2712,
)


_PENDINGRESOLVELIST = _descriptor.Descriptor(
  name='PendingResolveList',
  full_name='oracle.v1.PendingResolveList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_ids', full_name='oracle.v1.PendingResolveList.request_ids', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2714,
  serialized_end=2761,
)


_IBCCHANNEL = _descriptor.Descriptor(
  name='IBCChannel',
  full_name='oracle.v1.IBCChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='oracle.v1.IBCChannel.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='oracle.v1.IBCChannel.channel_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2763,
  serialized_end=2818,
)


_REPORTERSPERVALIDATOR = _descriptor.Descriptor(
  name='ReportersPerValidator',
  full_name='oracle.v1.ReportersPerValidator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.ReportersPerValidator.validator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reporters', full_name='oracle.v1.ReportersPerValidator.reporters', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2820,
  serialized_end=2887,
)


_REQUESTVERIFICATION = _descriptor.Descriptor(
  name='RequestVerification',
  full_name='oracle.v1.RequestVerification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='oracle.v1.RequestVerification.chain_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\007ChainID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='oracle.v1.RequestVerification.validator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.RequestVerification.request_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\tRequestID\372\336\037\tRequestID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_id', full_name='oracle.v1.RequestVerification.external_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\nExternalID\372\336\037\nExternalID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2890,
  serialized_end=3066,
)


_PRICERESULT = _descriptor.Descriptor(
  name='PriceResult',
  full_name='oracle.v1.PriceResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='oracle.v1.PriceResult.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multiplier', full_name='oracle.v1.PriceResult.multiplier', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='px', full_name='oracle.v1.PriceResult.px', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='oracle.v1.PriceResult.request_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\tRequestID\372\336\037\tRequestID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_time', full_name='oracle.v1.PriceResult.resolve_time', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3069,
  serialized_end=3200,
)

_DATASOURCE.fields_by_name['fee'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_REQUEST.fields_by_name['raw_requests'].message_type = _RAWREQUEST
_REQUEST.fields_by_name['ibc_channel'].message_type = _IBCCHANNEL
_REPORT.fields_by_name['raw_reports'].message_type = _RAWREPORT
_ORACLEREQUESTPACKETDATA.fields_by_name['fee_limit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_ORACLERESPONSEPACKETDATA.fields_by_name['resolve_status'].enum_type = _RESOLVESTATUS
_RESULT.fields_by_name['resolve_status'].enum_type = _RESOLVESTATUS
_VALIDATORSTATUS.fields_by_name['since'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['DataSource'] = _DATASOURCE
DESCRIPTOR.message_types_by_name['OracleScript'] = _ORACLESCRIPT
DESCRIPTOR.message_types_by_name['RawRequest'] = _RAWREQUEST
DESCRIPTOR.message_types_by_name['RawReport'] = _RAWREPORT
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Report'] = _REPORT
DESCRIPTOR.message_types_by_name['OracleRequestPacketData'] = _ORACLEREQUESTPACKETDATA
DESCRIPTOR.message_types_by_name['OracleRequestPacketAcknowledgement'] = _ORACLEREQUESTPACKETACKNOWLEDGEMENT
DESCRIPTOR.message_types_by_name['OracleResponsePacketData'] = _ORACLERESPONSEPACKETDATA
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
DESCRIPTOR.message_types_by_name['ValidatorStatus'] = _VALIDATORSTATUS
DESCRIPTOR.message_types_by_name['ActiveValidator'] = _ACTIVEVALIDATOR
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.message_types_by_name['PendingResolveList'] = _PENDINGRESOLVELIST
DESCRIPTOR.message_types_by_name['IBCChannel'] = _IBCCHANNEL
DESCRIPTOR.message_types_by_name['ReportersPerValidator'] = _REPORTERSPERVALIDATOR
DESCRIPTOR.message_types_by_name['RequestVerification'] = _REQUESTVERIFICATION
DESCRIPTOR.message_types_by_name['PriceResult'] = _PRICERESULT
DESCRIPTOR.enum_types_by_name['ResolveStatus'] = _RESOLVESTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataSource = _reflection.GeneratedProtocolMessageType('DataSource', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCE,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.DataSource)
  })
_sym_db.RegisterMessage(DataSource)

OracleScript = _reflection.GeneratedProtocolMessageType('OracleScript', (_message.Message,), {
  'DESCRIPTOR' : _ORACLESCRIPT,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.OracleScript)
  })
_sym_db.RegisterMessage(OracleScript)

RawRequest = _reflection.GeneratedProtocolMessageType('RawRequest', (_message.Message,), {
  'DESCRIPTOR' : _RAWREQUEST,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.RawRequest)
  })
_sym_db.RegisterMessage(RawRequest)

RawReport = _reflection.GeneratedProtocolMessageType('RawReport', (_message.Message,), {
  'DESCRIPTOR' : _RAWREPORT,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.RawReport)
  })
_sym_db.RegisterMessage(RawReport)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.Request)
  })
_sym_db.RegisterMessage(Request)

Report = _reflection.GeneratedProtocolMessageType('Report', (_message.Message,), {
  'DESCRIPTOR' : _REPORT,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.Report)
  })
_sym_db.RegisterMessage(Report)

OracleRequestPacketData = _reflection.GeneratedProtocolMessageType('OracleRequestPacketData', (_message.Message,), {
  'DESCRIPTOR' : _ORACLEREQUESTPACKETDATA,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.OracleRequestPacketData)
  })
_sym_db.RegisterMessage(OracleRequestPacketData)

OracleRequestPacketAcknowledgement = _reflection.GeneratedProtocolMessageType('OracleRequestPacketAcknowledgement', (_message.Message,), {
  'DESCRIPTOR' : _ORACLEREQUESTPACKETACKNOWLEDGEMENT,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.OracleRequestPacketAcknowledgement)
  })
_sym_db.RegisterMessage(OracleRequestPacketAcknowledgement)

OracleResponsePacketData = _reflection.GeneratedProtocolMessageType('OracleResponsePacketData', (_message.Message,), {
  'DESCRIPTOR' : _ORACLERESPONSEPACKETDATA,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.OracleResponsePacketData)
  })
_sym_db.RegisterMessage(OracleResponsePacketData)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.Result)
  })
_sym_db.RegisterMessage(Result)

ValidatorStatus = _reflection.GeneratedProtocolMessageType('ValidatorStatus', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATORSTATUS,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.ValidatorStatus)
  })
_sym_db.RegisterMessage(ValidatorStatus)

ActiveValidator = _reflection.GeneratedProtocolMessageType('ActiveValidator', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVEVALIDATOR,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.ActiveValidator)
  })
_sym_db.RegisterMessage(ActiveValidator)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.Params)
  })
_sym_db.RegisterMessage(Params)

PendingResolveList = _reflection.GeneratedProtocolMessageType('PendingResolveList', (_message.Message,), {
  'DESCRIPTOR' : _PENDINGRESOLVELIST,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.PendingResolveList)
  })
_sym_db.RegisterMessage(PendingResolveList)

IBCChannel = _reflection.GeneratedProtocolMessageType('IBCChannel', (_message.Message,), {
  'DESCRIPTOR' : _IBCCHANNEL,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.IBCChannel)
  })
_sym_db.RegisterMessage(IBCChannel)

ReportersPerValidator = _reflection.GeneratedProtocolMessageType('ReportersPerValidator', (_message.Message,), {
  'DESCRIPTOR' : _REPORTERSPERVALIDATOR,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.ReportersPerValidator)
  })
_sym_db.RegisterMessage(ReportersPerValidator)

RequestVerification = _reflection.GeneratedProtocolMessageType('RequestVerification', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTVERIFICATION,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.RequestVerification)
  })
_sym_db.RegisterMessage(RequestVerification)

PriceResult = _reflection.GeneratedProtocolMessageType('PriceResult', (_message.Message,), {
  'DESCRIPTOR' : _PRICERESULT,
  '__module__' : 'oracle.v1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.PriceResult)
  })
_sym_db.RegisterMessage(PriceResult)


DESCRIPTOR._options = None
_RESOLVESTATUS._options = None
_RESOLVESTATUS.values_by_name["RESOLVE_STATUS_OPEN_UNSPECIFIED"]._options = None
_RESOLVESTATUS.values_by_name["RESOLVE_STATUS_SUCCESS"]._options = None
_RESOLVESTATUS.values_by_name["RESOLVE_STATUS_FAILURE"]._options = None
_RESOLVESTATUS.values_by_name["RESOLVE_STATUS_EXPIRED"]._options = None
_DATASOURCE.fields_by_name['fee']._options = None
_DATASOURCE._options = None
_ORACLESCRIPT.fields_by_name['source_code_url']._options = None
_ORACLESCRIPT._options = None
_RAWREQUEST.fields_by_name['external_id']._options = None
_RAWREQUEST.fields_by_name['data_source_id']._options = None
_RAWREQUEST._options = None
_RAWREPORT.fields_by_name['external_id']._options = None
_RAWREPORT._options = None
_REQUEST.fields_by_name['oracle_script_id']._options = None
_REQUEST.fields_by_name['client_id']._options = None
_REQUEST.fields_by_name['raw_requests']._options = None
_REQUEST.fields_by_name['ibc_channel']._options = None
_REQUEST._options = None
_REPORT.fields_by_name['raw_reports']._options = None
_REPORT._options = None
_ORACLEREQUESTPACKETDATA.fields_by_name['client_id']._options = None
_ORACLEREQUESTPACKETDATA.fields_by_name['oracle_script_id']._options = None
_ORACLEREQUESTPACKETDATA.fields_by_name['fee_limit']._options = None
_ORACLEREQUESTPACKETDATA._options = None
_ORACLEREQUESTPACKETACKNOWLEDGEMENT.fields_by_name['request_id']._options = None
_ORACLEREQUESTPACKETACKNOWLEDGEMENT._options = None
_ORACLERESPONSEPACKETDATA.fields_by_name['client_id']._options = None
_ORACLERESPONSEPACKETDATA.fields_by_name['request_id']._options = None
_ORACLERESPONSEPACKETDATA._options = None
_RESULT.fields_by_name['client_id']._options = None
_RESULT.fields_by_name['oracle_script_id']._options = None
_RESULT.fields_by_name['request_id']._options = None
_RESULT._options = None
_VALIDATORSTATUS.fields_by_name['since']._options = None
_VALIDATORSTATUS._options = None
_PARAMS.fields_by_name['ibc_request_enabled']._options = None
_PARAMS._options = None
_PENDINGRESOLVELIST._options = None
_IBCCHANNEL._options = None
_REPORTERSPERVALIDATOR.fields_by_name['reporters']._options = None
_REQUESTVERIFICATION.fields_by_name['chain_id']._options = None
_REQUESTVERIFICATION.fields_by_name['request_id']._options = None
_REQUESTVERIFICATION.fields_by_name['external_id']._options = None
_REQUESTVERIFICATION._options = None
_PRICERESULT.fields_by_name['request_id']._options = None
# @@protoc_insertion_point(module_scope)
