"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import google.protobuf.descriptor

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

goproto_enum_prefix: google.protobuf.descriptor.FieldDescriptor = ...

goproto_enum_stringer: google.protobuf.descriptor.FieldDescriptor = ...

enum_stringer: google.protobuf.descriptor.FieldDescriptor = ...

enum_customname: google.protobuf.descriptor.FieldDescriptor = ...

enumdecl: google.protobuf.descriptor.FieldDescriptor = ...

enumvalue_customname: google.protobuf.descriptor.FieldDescriptor = ...

goproto_getters_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_enum_prefix_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_stringer_all: google.protobuf.descriptor.FieldDescriptor = ...

verbose_equal_all: google.protobuf.descriptor.FieldDescriptor = ...

face_all: google.protobuf.descriptor.FieldDescriptor = ...

gostring_all: google.protobuf.descriptor.FieldDescriptor = ...

populate_all: google.protobuf.descriptor.FieldDescriptor = ...

stringer_all: google.protobuf.descriptor.FieldDescriptor = ...

onlyone_all: google.protobuf.descriptor.FieldDescriptor = ...

equal_all: google.protobuf.descriptor.FieldDescriptor = ...

description_all: google.protobuf.descriptor.FieldDescriptor = ...

testgen_all: google.protobuf.descriptor.FieldDescriptor = ...

benchgen_all: google.protobuf.descriptor.FieldDescriptor = ...

marshaler_all: google.protobuf.descriptor.FieldDescriptor = ...

unmarshaler_all: google.protobuf.descriptor.FieldDescriptor = ...

stable_marshaler_all: google.protobuf.descriptor.FieldDescriptor = ...

sizer_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_enum_stringer_all: google.protobuf.descriptor.FieldDescriptor = ...

enum_stringer_all: google.protobuf.descriptor.FieldDescriptor = ...

unsafe_marshaler_all: google.protobuf.descriptor.FieldDescriptor = ...

unsafe_unmarshaler_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_extensions_map_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_unrecognized_all: google.protobuf.descriptor.FieldDescriptor = ...

gogoproto_import: google.protobuf.descriptor.FieldDescriptor = ...

protosizer_all: google.protobuf.descriptor.FieldDescriptor = ...

compare_all: google.protobuf.descriptor.FieldDescriptor = ...

typedecl_all: google.protobuf.descriptor.FieldDescriptor = ...

enumdecl_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_registration: google.protobuf.descriptor.FieldDescriptor = ...

messagename_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_sizecache_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_unkeyed_all: google.protobuf.descriptor.FieldDescriptor = ...

goproto_getters: google.protobuf.descriptor.FieldDescriptor = ...

goproto_stringer: google.protobuf.descriptor.FieldDescriptor = ...

verbose_equal: google.protobuf.descriptor.FieldDescriptor = ...

face: google.protobuf.descriptor.FieldDescriptor = ...

gostring: google.protobuf.descriptor.FieldDescriptor = ...

populate: google.protobuf.descriptor.FieldDescriptor = ...

stringer: google.protobuf.descriptor.FieldDescriptor = ...

onlyone: google.protobuf.descriptor.FieldDescriptor = ...

equal: google.protobuf.descriptor.FieldDescriptor = ...

description: google.protobuf.descriptor.FieldDescriptor = ...

testgen: google.protobuf.descriptor.FieldDescriptor = ...

benchgen: google.protobuf.descriptor.FieldDescriptor = ...

marshaler: google.protobuf.descriptor.FieldDescriptor = ...

unmarshaler: google.protobuf.descriptor.FieldDescriptor = ...

stable_marshaler: google.protobuf.descriptor.FieldDescriptor = ...

sizer: google.protobuf.descriptor.FieldDescriptor = ...

unsafe_marshaler: google.protobuf.descriptor.FieldDescriptor = ...

unsafe_unmarshaler: google.protobuf.descriptor.FieldDescriptor = ...

goproto_extensions_map: google.protobuf.descriptor.FieldDescriptor = ...

goproto_unrecognized: google.protobuf.descriptor.FieldDescriptor = ...

protosizer: google.protobuf.descriptor.FieldDescriptor = ...

compare: google.protobuf.descriptor.FieldDescriptor = ...

typedecl: google.protobuf.descriptor.FieldDescriptor = ...

messagename: google.protobuf.descriptor.FieldDescriptor = ...

goproto_sizecache: google.protobuf.descriptor.FieldDescriptor = ...

goproto_unkeyed: google.protobuf.descriptor.FieldDescriptor = ...

nullable: google.protobuf.descriptor.FieldDescriptor = ...

embed: google.protobuf.descriptor.FieldDescriptor = ...

customtype: google.protobuf.descriptor.FieldDescriptor = ...

customname: google.protobuf.descriptor.FieldDescriptor = ...

jsontag: google.protobuf.descriptor.FieldDescriptor = ...

moretags: google.protobuf.descriptor.FieldDescriptor = ...

casttype: google.protobuf.descriptor.FieldDescriptor = ...

castkey: google.protobuf.descriptor.FieldDescriptor = ...

castvalue: google.protobuf.descriptor.FieldDescriptor = ...

stdtime: google.protobuf.descriptor.FieldDescriptor = ...

stdduration: google.protobuf.descriptor.FieldDescriptor = ...

wktpointer: google.protobuf.descriptor.FieldDescriptor = ...

castrepeated: google.protobuf.descriptor.FieldDescriptor = ...
