"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.message
import ibc.core.client.v1.client_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MsgTransfer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SOURCE_PORT_FIELD_NUMBER: builtins.int
    SOURCE_CHANNEL_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    RECEIVER_FIELD_NUMBER: builtins.int
    TIMEOUT_HEIGHT_FIELD_NUMBER: builtins.int
    TIMEOUT_TIMESTAMP_FIELD_NUMBER: builtins.int
    source_port: typing.Text = ...
    source_channel: typing.Text = ...
    sender: typing.Text = ...
    receiver: typing.Text = ...
    timeout_timestamp: builtins.int = ...

    @property
    def token(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...

    @property
    def timeout_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        source_port : typing.Text = ...,
        source_channel : typing.Text = ...,
        token : typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        sender : typing.Text = ...,
        receiver : typing.Text = ...,
        timeout_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        timeout_timestamp : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"timeout_height",b"timeout_height",u"token",b"token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"receiver",b"receiver",u"sender",b"sender",u"source_channel",b"source_channel",u"source_port",b"source_port",u"timeout_height",b"timeout_height",u"timeout_timestamp",b"timeout_timestamp",u"token",b"token"]) -> None: ...
global___MsgTransfer = MsgTransfer

class MsgTransferResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgTransferResponse = MsgTransferResponse
