"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MsgVerifyInvariant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SENDER_FIELD_NUMBER: builtins.int
    INVARIANT_MODULE_NAME_FIELD_NUMBER: builtins.int
    INVARIANT_ROUTE_FIELD_NUMBER: builtins.int
    sender: typing.Text = ...
    invariant_module_name: typing.Text = ...
    invariant_route: typing.Text = ...

    def __init__(self,
        *,
        sender : typing.Text = ...,
        invariant_module_name : typing.Text = ...,
        invariant_route : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"invariant_module_name",b"invariant_module_name",u"invariant_route",b"invariant_route",u"sender",b"sender"]) -> None: ...
global___MsgVerifyInvariant = MsgVerifyInvariant

class MsgVerifyInvariantResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgVerifyInvariantResponse = MsgVerifyInvariantResponse
