"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Plan(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    UPGRADED_CLIENT_STATE_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    height: builtins.int = ...
    info: typing.Text = ...

    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    @property
    def upgraded_client_state(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        name : typing.Text = ...,
        time : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        height : builtins.int = ...,
        info : typing.Text = ...,
        upgraded_client_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"time",b"time",u"upgraded_client_state",b"upgraded_client_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"height",b"height",u"info",b"info",u"name",b"name",u"time",b"time",u"upgraded_client_state",b"upgraded_client_state"]) -> None: ...
global___Plan = Plan

class SoftwareUpgradeProposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PLAN_FIELD_NUMBER: builtins.int
    title: typing.Text = ...
    description: typing.Text = ...

    @property
    def plan(self) -> global___Plan: ...

    def __init__(self,
        *,
        title : typing.Text = ...,
        description : typing.Text = ...,
        plan : typing.Optional[global___Plan] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"plan",b"plan"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"description",b"description",u"plan",b"plan",u"title",b"title"]) -> None: ...
global___SoftwareUpgradeProposal = SoftwareUpgradeProposal

class CancelSoftwareUpgradeProposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    title: typing.Text = ...
    description: typing.Text = ...

    def __init__(self,
        *,
        title : typing.Text = ...,
        description : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"description",b"description",u"title",b"title"]) -> None: ...
global___CancelSoftwareUpgradeProposal = CancelSoftwareUpgradeProposal
