"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class IdentifiedClientState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_STATE_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...

    @property
    def client_state(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        client_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"client_state",b"client_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"client_state",b"client_state"]) -> None: ...
global___IdentifiedClientState = IdentifiedClientState

class ConsensusStateWithHeight(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_FIELD_NUMBER: builtins.int
    CONSENSUS_STATE_FIELD_NUMBER: builtins.int

    @property
    def height(self) -> global___Height: ...

    @property
    def consensus_state(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        height : typing.Optional[global___Height] = ...,
        consensus_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"consensus_state",b"consensus_state",u"height",b"height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"consensus_state",b"consensus_state",u"height",b"height"]) -> None: ...
global___ConsensusStateWithHeight = ConsensusStateWithHeight

class ClientConsensusStates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CONSENSUS_STATES_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...

    @property
    def consensus_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConsensusStateWithHeight]: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        consensus_states : typing.Optional[typing.Iterable[global___ConsensusStateWithHeight]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"consensus_states",b"consensus_states"]) -> None: ...
global___ClientConsensusStates = ClientConsensusStates

class ClientUpdateProposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    HEADER_FIELD_NUMBER: builtins.int
    title: typing.Text = ...
    description: typing.Text = ...
    client_id: typing.Text = ...

    @property
    def header(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        title : typing.Text = ...,
        description : typing.Text = ...,
        client_id : typing.Text = ...,
        header : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"description",b"description",u"header",b"header",u"title",b"title"]) -> None: ...
global___ClientUpdateProposal = ClientUpdateProposal

class Height(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REVISION_NUMBER_FIELD_NUMBER: builtins.int
    REVISION_HEIGHT_FIELD_NUMBER: builtins.int
    revision_number: builtins.int = ...
    revision_height: builtins.int = ...

    def __init__(self,
        *,
        revision_number : builtins.int = ...,
        revision_height : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"revision_height",b"revision_height",u"revision_number",b"revision_number"]) -> None: ...
global___Height = Height

class Params(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ALLOWED_CLIENTS_FIELD_NUMBER: builtins.int

    @property
    def allowed_clients(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        allowed_clients : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"allowed_clients",b"allowed_clients"]) -> None: ...
global___Params = Params
