"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Validators:grpc.UnaryUnaryMultiCallable[
        global___QueryValidatorsRequest,
        global___QueryValidatorsResponse] = ...

    Validator:grpc.UnaryUnaryMultiCallable[
        global___QueryValidatorRequest,
        global___QueryValidatorResponse] = ...

    ValidatorDelegations:grpc.UnaryUnaryMultiCallable[
        global___QueryValidatorDelegationsRequest,
        global___QueryValidatorDelegationsResponse] = ...

    ValidatorUnbondingDelegations:grpc.UnaryUnaryMultiCallable[
        global___QueryValidatorUnbondingDelegationsRequest,
        global___QueryValidatorUnbondingDelegationsResponse] = ...

    Delegation:grpc.UnaryUnaryMultiCallable[
        global___QueryDelegationRequest,
        global___QueryDelegationResponse] = ...

    UnbondingDelegation:grpc.UnaryUnaryMultiCallable[
        global___QueryUnbondingDelegationRequest,
        global___QueryUnbondingDelegationResponse] = ...

    DelegatorDelegations:grpc.UnaryUnaryMultiCallable[
        global___QueryDelegatorDelegationsRequest,
        global___QueryDelegatorDelegationsResponse] = ...

    DelegatorUnbondingDelegations:grpc.UnaryUnaryMultiCallable[
        global___QueryDelegatorUnbondingDelegationsRequest,
        global___QueryDelegatorUnbondingDelegationsResponse] = ...

    Redelegations:grpc.UnaryUnaryMultiCallable[
        global___QueryRedelegationsRequest,
        global___QueryRedelegationsResponse] = ...

    DelegatorValidators:grpc.UnaryUnaryMultiCallable[
        global___QueryDelegatorValidatorsRequest,
        global___QueryDelegatorValidatorsResponse] = ...

    DelegatorValidator:grpc.UnaryUnaryMultiCallable[
        global___QueryDelegatorValidatorRequest,
        global___QueryDelegatorValidatorResponse] = ...

    HistoricalInfo:grpc.UnaryUnaryMultiCallable[
        global___QueryHistoricalInfoRequest,
        global___QueryHistoricalInfoResponse] = ...

    Pool:grpc.UnaryUnaryMultiCallable[
        global___QueryPoolRequest,
        global___QueryPoolResponse] = ...

    Params:grpc.UnaryUnaryMultiCallable[
        global___QueryParamsRequest,
        global___QueryParamsResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Validators(self,
        request: global___QueryValidatorsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryValidatorsResponse: ...

    @abc.abstractmethod
    def Validator(self,
        request: global___QueryValidatorRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryValidatorResponse: ...

    @abc.abstractmethod
    def ValidatorDelegations(self,
        request: global___QueryValidatorDelegationsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryValidatorDelegationsResponse: ...

    @abc.abstractmethod
    def ValidatorUnbondingDelegations(self,
        request: global___QueryValidatorUnbondingDelegationsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryValidatorUnbondingDelegationsResponse: ...

    @abc.abstractmethod
    def Delegation(self,
        request: global___QueryDelegationRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDelegationResponse: ...

    @abc.abstractmethod
    def UnbondingDelegation(self,
        request: global___QueryUnbondingDelegationRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryUnbondingDelegationResponse: ...

    @abc.abstractmethod
    def DelegatorDelegations(self,
        request: global___QueryDelegatorDelegationsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDelegatorDelegationsResponse: ...

    @abc.abstractmethod
    def DelegatorUnbondingDelegations(self,
        request: global___QueryDelegatorUnbondingDelegationsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDelegatorUnbondingDelegationsResponse: ...

    @abc.abstractmethod
    def Redelegations(self,
        request: global___QueryRedelegationsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryRedelegationsResponse: ...

    @abc.abstractmethod
    def DelegatorValidators(self,
        request: global___QueryDelegatorValidatorsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDelegatorValidatorsResponse: ...

    @abc.abstractmethod
    def DelegatorValidator(self,
        request: global___QueryDelegatorValidatorRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryDelegatorValidatorResponse: ...

    @abc.abstractmethod
    def HistoricalInfo(self,
        request: global___QueryHistoricalInfoRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryHistoricalInfoResponse: ...

    @abc.abstractmethod
    def Pool(self,
        request: global___QueryPoolRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryPoolResponse: ...

    @abc.abstractmethod
    def Params(self,
        request: global___QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryParamsResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
