"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.well_known_types
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Any(google.protobuf.message.Message, google.protobuf.internal.well_known_types.Any):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_URL_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    type_url: typing.Text = ...
    value: builtins.bytes = ...

    def __init__(self,
        *,
        type_url : typing.Text = ...,
        value : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"type_url",b"type_url",u"value",b"value"]) -> None: ...
global___Any = Any
