"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONSTANT_FEE_FIELD_NUMBER: builtins.int

    @property
    def constant_fee(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...

    def __init__(self,
        *,
        constant_fee : typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"constant_fee",b"constant_fee"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"constant_fee",b"constant_fee"]) -> None: ...
global___GenesisState = GenesisState
