"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.query.v1beta1.pagination_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import tendermint.p2p.types_pb2
import tendermint.types.block_pb2
import tendermint.types.types_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetValidatorSetByHeightRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    height: builtins.int = ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        height : builtins.int = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"height",b"height",u"pagination",b"pagination"]) -> None: ...
global___GetValidatorSetByHeightRequest = GetValidatorSetByHeightRequest

class GetValidatorSetByHeightResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BLOCK_HEIGHT_FIELD_NUMBER: builtins.int
    VALIDATORS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    block_height: builtins.int = ...

    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Validator]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    def __init__(self,
        *,
        block_height : builtins.int = ...,
        validators : typing.Optional[typing.Iterable[global___Validator]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block_height",b"block_height",u"pagination",b"pagination",u"validators",b"validators"]) -> None: ...
global___GetValidatorSetByHeightResponse = GetValidatorSetByHeightResponse

class GetLatestValidatorSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> None: ...
global___GetLatestValidatorSetRequest = GetLatestValidatorSetRequest

class GetLatestValidatorSetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BLOCK_HEIGHT_FIELD_NUMBER: builtins.int
    VALIDATORS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    block_height: builtins.int = ...

    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Validator]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    def __init__(self,
        *,
        block_height : builtins.int = ...,
        validators : typing.Optional[typing.Iterable[global___Validator]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block_height",b"block_height",u"pagination",b"pagination",u"validators",b"validators"]) -> None: ...
global___GetLatestValidatorSetResponse = GetLatestValidatorSetResponse

class Validator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    PUB_KEY_FIELD_NUMBER: builtins.int
    VOTING_POWER_FIELD_NUMBER: builtins.int
    PROPOSER_PRIORITY_FIELD_NUMBER: builtins.int
    address: typing.Text = ...
    voting_power: builtins.int = ...
    proposer_priority: builtins.int = ...

    @property
    def pub_key(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        pub_key : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        voting_power : builtins.int = ...,
        proposer_priority : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pub_key",b"pub_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"address",b"address",u"proposer_priority",b"proposer_priority",u"pub_key",b"pub_key",u"voting_power",b"voting_power"]) -> None: ...
global___Validator = Validator

class GetBlockByHeightRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_FIELD_NUMBER: builtins.int
    height: builtins.int = ...

    def __init__(self,
        *,
        height : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"height",b"height"]) -> None: ...
global___GetBlockByHeightRequest = GetBlockByHeightRequest

class GetBlockByHeightResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BLOCK_ID_FIELD_NUMBER: builtins.int
    BLOCK_FIELD_NUMBER: builtins.int

    @property
    def block_id(self) -> tendermint.types.types_pb2.BlockID: ...

    @property
    def block(self) -> tendermint.types.block_pb2.Block: ...

    def __init__(self,
        *,
        block_id : typing.Optional[tendermint.types.types_pb2.BlockID] = ...,
        block : typing.Optional[tendermint.types.block_pb2.Block] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"block",b"block",u"block_id",b"block_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block",b"block",u"block_id",b"block_id"]) -> None: ...
global___GetBlockByHeightResponse = GetBlockByHeightResponse

class GetLatestBlockRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___GetLatestBlockRequest = GetLatestBlockRequest

class GetLatestBlockResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BLOCK_ID_FIELD_NUMBER: builtins.int
    BLOCK_FIELD_NUMBER: builtins.int

    @property
    def block_id(self) -> tendermint.types.types_pb2.BlockID: ...

    @property
    def block(self) -> tendermint.types.block_pb2.Block: ...

    def __init__(self,
        *,
        block_id : typing.Optional[tendermint.types.types_pb2.BlockID] = ...,
        block : typing.Optional[tendermint.types.block_pb2.Block] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"block",b"block",u"block_id",b"block_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block",b"block",u"block_id",b"block_id"]) -> None: ...
global___GetLatestBlockResponse = GetLatestBlockResponse

class GetSyncingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___GetSyncingRequest = GetSyncingRequest

class GetSyncingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SYNCING_FIELD_NUMBER: builtins.int
    syncing: builtins.bool = ...

    def __init__(self,
        *,
        syncing : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"syncing",b"syncing"]) -> None: ...
global___GetSyncingResponse = GetSyncingResponse

class GetNodeInfoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___GetNodeInfoRequest = GetNodeInfoRequest

class GetNodeInfoResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DEFAULT_NODE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_VERSION_FIELD_NUMBER: builtins.int

    @property
    def default_node_info(self) -> tendermint.p2p.types_pb2.DefaultNodeInfo: ...

    @property
    def application_version(self) -> global___VersionInfo: ...

    def __init__(self,
        *,
        default_node_info : typing.Optional[tendermint.p2p.types_pb2.DefaultNodeInfo] = ...,
        application_version : typing.Optional[global___VersionInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"application_version",b"application_version",u"default_node_info",b"default_node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"application_version",b"application_version",u"default_node_info",b"default_node_info"]) -> None: ...
global___GetNodeInfoResponse = GetNodeInfoResponse

class VersionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    APP_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    GIT_COMMIT_FIELD_NUMBER: builtins.int
    BUILD_TAGS_FIELD_NUMBER: builtins.int
    GO_VERSION_FIELD_NUMBER: builtins.int
    BUILD_DEPS_FIELD_NUMBER: builtins.int
    COSMOS_SDK_VERSION_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    app_name: typing.Text = ...
    version: typing.Text = ...
    git_commit: typing.Text = ...
    build_tags: typing.Text = ...
    go_version: typing.Text = ...
    cosmos_sdk_version: typing.Text = ...

    @property
    def build_deps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Module]: ...

    def __init__(self,
        *,
        name : typing.Text = ...,
        app_name : typing.Text = ...,
        version : typing.Text = ...,
        git_commit : typing.Text = ...,
        build_tags : typing.Text = ...,
        go_version : typing.Text = ...,
        build_deps : typing.Optional[typing.Iterable[global___Module]] = ...,
        cosmos_sdk_version : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"app_name",b"app_name",u"build_deps",b"build_deps",u"build_tags",b"build_tags",u"cosmos_sdk_version",b"cosmos_sdk_version",u"git_commit",b"git_commit",u"go_version",b"go_version",u"name",b"name",u"version",b"version"]) -> None: ...
global___VersionInfo = VersionInfo

class Module(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PATH_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    SUM_FIELD_NUMBER: builtins.int
    path: typing.Text = ...
    version: typing.Text = ...
    sum: typing.Text = ...

    def __init__(self,
        *,
        path : typing.Text = ...,
        version : typing.Text = ...,
        sum : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"path",b"path",u"sum",b"sum",u"version",b"version"]) -> None: ...
global___Module = Module
