"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .service_pb2 import *
class ServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Simulate:grpc.UnaryUnaryMultiCallable[
        global___SimulateRequest,
        global___SimulateResponse] = ...

    GetTx:grpc.UnaryUnaryMultiCallable[
        global___GetTxRequest,
        global___GetTxResponse] = ...

    BroadcastTx:grpc.UnaryUnaryMultiCallable[
        global___BroadcastTxRequest,
        global___BroadcastTxResponse] = ...

    GetTxsEvent:grpc.UnaryUnaryMultiCallable[
        global___GetTxsEventRequest,
        global___GetTxsEventResponse] = ...


class ServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Simulate(self,
        request: global___SimulateRequest,
        context: grpc.ServicerContext,
    ) -> global___SimulateResponse: ...

    @abc.abstractmethod
    def GetTx(self,
        request: global___GetTxRequest,
        context: grpc.ServicerContext,
    ) -> global___GetTxResponse: ...

    @abc.abstractmethod
    def BroadcastTx(self,
        request: global___BroadcastTxRequest,
        context: grpc.ServicerContext,
    ) -> global___BroadcastTxResponse: ...

    @abc.abstractmethod
    def GetTxsEvent(self,
        request: global___GetTxsEventRequest,
        context: grpc.ServicerContext,
    ) -> global___GetTxsEventResponse: ...


def add_ServiceServicer_to_server(servicer: ServiceServicer, server: grpc.Server) -> None: ...
