"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import ibc.core.channel.v1.channel_pb2
import ibc.core.client.v1.client_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MsgChannelOpenInit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    signer: typing.Text = ...

    @property
    def channel(self) -> ibc.core.channel.v1.channel_pb2.Channel: ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel : typing.Optional[ibc.core.channel.v1.channel_pb2.Channel] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"channel",b"channel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel",b"channel",u"port_id",b"port_id",u"signer",b"signer"]) -> None: ...
global___MsgChannelOpenInit = MsgChannelOpenInit

class MsgChannelOpenInitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgChannelOpenInitResponse = MsgChannelOpenInitResponse

class MsgChannelOpenTry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    PREVIOUS_CHANNEL_ID_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    COUNTERPARTY_VERSION_FIELD_NUMBER: builtins.int
    PROOF_INIT_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    previous_channel_id: typing.Text = ...
    counterparty_version: typing.Text = ...
    proof_init: builtins.bytes = ...
    signer: typing.Text = ...

    @property
    def channel(self) -> ibc.core.channel.v1.channel_pb2.Channel: ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        previous_channel_id : typing.Text = ...,
        channel : typing.Optional[ibc.core.channel.v1.channel_pb2.Channel] = ...,
        counterparty_version : typing.Text = ...,
        proof_init : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"channel",b"channel",u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel",b"channel",u"counterparty_version",b"counterparty_version",u"port_id",b"port_id",u"previous_channel_id",b"previous_channel_id",u"proof_height",b"proof_height",u"proof_init",b"proof_init",u"signer",b"signer"]) -> None: ...
global___MsgChannelOpenTry = MsgChannelOpenTry

class MsgChannelOpenTryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgChannelOpenTryResponse = MsgChannelOpenTryResponse

class MsgChannelOpenAck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    COUNTERPARTY_CHANNEL_ID_FIELD_NUMBER: builtins.int
    COUNTERPARTY_VERSION_FIELD_NUMBER: builtins.int
    PROOF_TRY_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...
    counterparty_channel_id: typing.Text = ...
    counterparty_version: typing.Text = ...
    proof_try: builtins.bytes = ...
    signer: typing.Text = ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        counterparty_channel_id : typing.Text = ...,
        counterparty_version : typing.Text = ...,
        proof_try : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"counterparty_channel_id",b"counterparty_channel_id",u"counterparty_version",b"counterparty_version",u"port_id",b"port_id",u"proof_height",b"proof_height",u"proof_try",b"proof_try",u"signer",b"signer"]) -> None: ...
global___MsgChannelOpenAck = MsgChannelOpenAck

class MsgChannelOpenAckResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgChannelOpenAckResponse = MsgChannelOpenAckResponse

class MsgChannelOpenConfirm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PROOF_ACK_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...
    proof_ack: builtins.bytes = ...
    signer: typing.Text = ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        proof_ack : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"port_id",b"port_id",u"proof_ack",b"proof_ack",u"proof_height",b"proof_height",u"signer",b"signer"]) -> None: ...
global___MsgChannelOpenConfirm = MsgChannelOpenConfirm

class MsgChannelOpenConfirmResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgChannelOpenConfirmResponse = MsgChannelOpenConfirmResponse

class MsgChannelCloseInit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...
    signer: typing.Text = ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"port_id",b"port_id",u"signer",b"signer"]) -> None: ...
global___MsgChannelCloseInit = MsgChannelCloseInit

class MsgChannelCloseInitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgChannelCloseInitResponse = MsgChannelCloseInitResponse

class MsgChannelCloseConfirm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PROOF_INIT_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...
    proof_init: builtins.bytes = ...
    signer: typing.Text = ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        proof_init : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"port_id",b"port_id",u"proof_height",b"proof_height",u"proof_init",b"proof_init",u"signer",b"signer"]) -> None: ...
global___MsgChannelCloseConfirm = MsgChannelCloseConfirm

class MsgChannelCloseConfirmResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgChannelCloseConfirmResponse = MsgChannelCloseConfirmResponse

class MsgRecvPacket(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PACKET_FIELD_NUMBER: builtins.int
    PROOF_COMMITMENT_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    proof_commitment: builtins.bytes = ...
    signer: typing.Text = ...

    @property
    def packet(self) -> ibc.core.channel.v1.channel_pb2.Packet: ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        packet : typing.Optional[ibc.core.channel.v1.channel_pb2.Packet] = ...,
        proof_commitment : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"packet",b"packet",u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"packet",b"packet",u"proof_commitment",b"proof_commitment",u"proof_height",b"proof_height",u"signer",b"signer"]) -> None: ...
global___MsgRecvPacket = MsgRecvPacket

class MsgRecvPacketResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgRecvPacketResponse = MsgRecvPacketResponse

class MsgTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PACKET_FIELD_NUMBER: builtins.int
    PROOF_UNRECEIVED_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    NEXT_SEQUENCE_RECV_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    proof_unreceived: builtins.bytes = ...
    next_sequence_recv: builtins.int = ...
    signer: typing.Text = ...

    @property
    def packet(self) -> ibc.core.channel.v1.channel_pb2.Packet: ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        packet : typing.Optional[ibc.core.channel.v1.channel_pb2.Packet] = ...,
        proof_unreceived : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        next_sequence_recv : builtins.int = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"packet",b"packet",u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"next_sequence_recv",b"next_sequence_recv",u"packet",b"packet",u"proof_height",b"proof_height",u"proof_unreceived",b"proof_unreceived",u"signer",b"signer"]) -> None: ...
global___MsgTimeout = MsgTimeout

class MsgTimeoutResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgTimeoutResponse = MsgTimeoutResponse

class MsgTimeoutOnClose(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PACKET_FIELD_NUMBER: builtins.int
    PROOF_UNRECEIVED_FIELD_NUMBER: builtins.int
    PROOF_CLOSE_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    NEXT_SEQUENCE_RECV_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    proof_unreceived: builtins.bytes = ...
    proof_close: builtins.bytes = ...
    next_sequence_recv: builtins.int = ...
    signer: typing.Text = ...

    @property
    def packet(self) -> ibc.core.channel.v1.channel_pb2.Packet: ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        packet : typing.Optional[ibc.core.channel.v1.channel_pb2.Packet] = ...,
        proof_unreceived : builtins.bytes = ...,
        proof_close : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        next_sequence_recv : builtins.int = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"packet",b"packet",u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"next_sequence_recv",b"next_sequence_recv",u"packet",b"packet",u"proof_close",b"proof_close",u"proof_height",b"proof_height",u"proof_unreceived",b"proof_unreceived",u"signer",b"signer"]) -> None: ...
global___MsgTimeoutOnClose = MsgTimeoutOnClose

class MsgTimeoutOnCloseResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgTimeoutOnCloseResponse = MsgTimeoutOnCloseResponse

class MsgAcknowledgement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PACKET_FIELD_NUMBER: builtins.int
    ACKNOWLEDGEMENT_FIELD_NUMBER: builtins.int
    PROOF_ACKED_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    acknowledgement: builtins.bytes = ...
    proof_acked: builtins.bytes = ...
    signer: typing.Text = ...

    @property
    def packet(self) -> ibc.core.channel.v1.channel_pb2.Packet: ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        packet : typing.Optional[ibc.core.channel.v1.channel_pb2.Packet] = ...,
        acknowledgement : builtins.bytes = ...,
        proof_acked : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"packet",b"packet",u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"acknowledgement",b"acknowledgement",u"packet",b"packet",u"proof_acked",b"proof_acked",u"proof_height",b"proof_height",u"signer",b"signer"]) -> None: ...
global___MsgAcknowledgement = MsgAcknowledgement

class MsgAcknowledgementResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgAcknowledgementResponse = MsgAcknowledgementResponse
