"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import google.protobuf.descriptor

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

interface_type: google.protobuf.descriptor.FieldDescriptor = ...

implements_interface: google.protobuf.descriptor.FieldDescriptor = ...

accepts_interface: google.protobuf.descriptor.FieldDescriptor = ...
