"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class NetAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ID_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    id: typing.Text = ...
    ip: typing.Text = ...
    port: builtins.int = ...

    def __init__(self,
        *,
        id : typing.Text = ...,
        ip : typing.Text = ...,
        port : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"id",b"id",u"ip",b"ip",u"port",b"port"]) -> None: ...
global___NetAddress = NetAddress

class ProtocolVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    P2P_FIELD_NUMBER: builtins.int
    BLOCK_FIELD_NUMBER: builtins.int
    APP_FIELD_NUMBER: builtins.int
    p2p: builtins.int = ...
    block: builtins.int = ...
    app: builtins.int = ...

    def __init__(self,
        *,
        p2p : builtins.int = ...,
        block : builtins.int = ...,
        app : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"app",b"app",u"block",b"block",u"p2p",b"p2p"]) -> None: ...
global___ProtocolVersion = ProtocolVersion

class DefaultNodeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROTOCOL_VERSION_FIELD_NUMBER: builtins.int
    DEFAULT_NODE_ID_FIELD_NUMBER: builtins.int
    LISTEN_ADDR_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    CHANNELS_FIELD_NUMBER: builtins.int
    MONIKER_FIELD_NUMBER: builtins.int
    OTHER_FIELD_NUMBER: builtins.int
    default_node_id: typing.Text = ...
    listen_addr: typing.Text = ...
    network: typing.Text = ...
    version: typing.Text = ...
    channels: builtins.bytes = ...
    moniker: typing.Text = ...

    @property
    def protocol_version(self) -> global___ProtocolVersion: ...

    @property
    def other(self) -> global___DefaultNodeInfoOther: ...

    def __init__(self,
        *,
        protocol_version : typing.Optional[global___ProtocolVersion] = ...,
        default_node_id : typing.Text = ...,
        listen_addr : typing.Text = ...,
        network : typing.Text = ...,
        version : typing.Text = ...,
        channels : builtins.bytes = ...,
        moniker : typing.Text = ...,
        other : typing.Optional[global___DefaultNodeInfoOther] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"other",b"other",u"protocol_version",b"protocol_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channels",b"channels",u"default_node_id",b"default_node_id",u"listen_addr",b"listen_addr",u"moniker",b"moniker",u"network",b"network",u"other",b"other",u"protocol_version",b"protocol_version",u"version",b"version"]) -> None: ...
global___DefaultNodeInfo = DefaultNodeInfo

class DefaultNodeInfoOther(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TX_INDEX_FIELD_NUMBER: builtins.int
    RPC_ADDRESS_FIELD_NUMBER: builtins.int
    tx_index: typing.Text = ...
    rpc_address: typing.Text = ...

    def __init__(self,
        *,
        tx_index : typing.Text = ...,
        rpc_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"rpc_address",b"rpc_address",u"tx_index",b"tx_index"]) -> None: ...
global___DefaultNodeInfoOther = DefaultNodeInfoOther
