"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.upgrade.v1beta1.upgrade_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryCurrentPlanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryCurrentPlanRequest = QueryCurrentPlanRequest

class QueryCurrentPlanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PLAN_FIELD_NUMBER: builtins.int

    @property
    def plan(self) -> cosmos.upgrade.v1beta1.upgrade_pb2.Plan: ...

    def __init__(self,
        *,
        plan : typing.Optional[cosmos.upgrade.v1beta1.upgrade_pb2.Plan] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"plan",b"plan"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"plan",b"plan"]) -> None: ...
global___QueryCurrentPlanResponse = QueryCurrentPlanResponse

class QueryAppliedPlanRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    name: typing.Text = ...

    def __init__(self,
        *,
        name : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"name",b"name"]) -> None: ...
global___QueryAppliedPlanRequest = QueryAppliedPlanRequest

class QueryAppliedPlanResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_FIELD_NUMBER: builtins.int
    height: builtins.int = ...

    def __init__(self,
        *,
        height : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"height",b"height"]) -> None: ...
global___QueryAppliedPlanResponse = QueryAppliedPlanResponse

class QueryUpgradedConsensusStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LAST_HEIGHT_FIELD_NUMBER: builtins.int
    last_height: builtins.int = ...

    def __init__(self,
        *,
        last_height : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"last_height",b"last_height"]) -> None: ...
global___QueryUpgradedConsensusStateRequest = QueryUpgradedConsensusStateRequest

class QueryUpgradedConsensusStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    UPGRADED_CONSENSUS_STATE_FIELD_NUMBER: builtins.int

    @property
    def upgraded_consensus_state(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        upgraded_consensus_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"upgraded_consensus_state",b"upgraded_consensus_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"upgraded_consensus_state",b"upgraded_consensus_state"]) -> None: ...
global___QueryUpgradedConsensusStateResponse = QueryUpgradedConsensusStateResponse
