"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import ibc.core.connection.v1.connection_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONNECTIONS_FIELD_NUMBER: builtins.int
    CLIENT_CONNECTION_PATHS_FIELD_NUMBER: builtins.int
    NEXT_CONNECTION_SEQUENCE_FIELD_NUMBER: builtins.int
    next_connection_sequence: builtins.int = ...

    @property
    def connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.core.connection.v1.connection_pb2.IdentifiedConnection]: ...

    @property
    def client_connection_paths(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.core.connection.v1.connection_pb2.ConnectionPaths]: ...

    def __init__(self,
        *,
        connections : typing.Optional[typing.Iterable[ibc.core.connection.v1.connection_pb2.IdentifiedConnection]] = ...,
        client_connection_paths : typing.Optional[typing.Iterable[ibc.core.connection.v1.connection_pb2.ConnectionPaths]] = ...,
        next_connection_sequence : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_connection_paths",b"client_connection_paths",u"connections",b"connections",u"next_connection_sequence",b"next_connection_sequence"]) -> None: ...
global___GenesisState = GenesisState
