"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Capability(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INDEX_FIELD_NUMBER: builtins.int
    index: builtins.int = ...

    def __init__(self,
        *,
        index : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"index",b"index"]) -> None: ...
global___Capability = Capability

class Owner(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MODULE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    module: typing.Text = ...
    name: typing.Text = ...

    def __init__(self,
        *,
        module : typing.Text = ...,
        name : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"module",b"module",u"name",b"name"]) -> None: ...
global___Owner = Owner

class CapabilityOwners(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OWNERS_FIELD_NUMBER: builtins.int

    @property
    def owners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Owner]: ...

    def __init__(self,
        *,
        owners : typing.Optional[typing.Iterable[global___Owner]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"owners",b"owners"]) -> None: ...
global___CapabilityOwners = CapabilityOwners
