"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SnapshotItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STORE_FIELD_NUMBER: builtins.int
    IAVL_FIELD_NUMBER: builtins.int

    @property
    def store(self) -> global___SnapshotStoreItem: ...

    @property
    def iavl(self) -> global___SnapshotIAVLItem: ...

    def __init__(self,
        *,
        store : typing.Optional[global___SnapshotStoreItem] = ...,
        iavl : typing.Optional[global___SnapshotIAVLItem] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"iavl",b"iavl",u"item",b"item",u"store",b"store"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"iavl",b"iavl",u"item",b"item",u"store",b"store"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"item",b"item"]) -> typing.Optional[typing_extensions.Literal["store","iavl"]]: ...
global___SnapshotItem = SnapshotItem

class SnapshotStoreItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    name: typing.Text = ...

    def __init__(self,
        *,
        name : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"name",b"name"]) -> None: ...
global___SnapshotStoreItem = SnapshotStoreItem

class SnapshotIAVLItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    key: builtins.bytes = ...
    value: builtins.bytes = ...
    version: builtins.int = ...
    height: builtins.int = ...

    def __init__(self,
        *,
        key : builtins.bytes = ...,
        value : builtins.bytes = ...,
        version : builtins.int = ...,
        height : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"height",b"height",u"key",b"key",u"value",b"value",u"version",b"version"]) -> None: ...
global___SnapshotIAVLItem = SnapshotIAVLItem
