"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .tx_pb2 import *
class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    SetWithdrawAddress:grpc.UnaryUnaryMultiCallable[
        global___MsgSetWithdrawAddress,
        global___MsgSetWithdrawAddressResponse] = ...

    WithdrawDelegatorReward:grpc.UnaryUnaryMultiCallable[
        global___MsgWithdrawDelegatorReward,
        global___MsgWithdrawDelegatorRewardResponse] = ...

    WithdrawValidatorCommission:grpc.UnaryUnaryMultiCallable[
        global___MsgWithdrawValidatorCommission,
        global___MsgWithdrawValidatorCommissionResponse] = ...

    FundCommunityPool:grpc.UnaryUnaryMultiCallable[
        global___MsgFundCommunityPool,
        global___MsgFundCommunityPoolResponse] = ...


class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def SetWithdrawAddress(self,
        request: global___MsgSetWithdrawAddress,
        context: grpc.ServicerContext,
    ) -> global___MsgSetWithdrawAddressResponse: ...

    @abc.abstractmethod
    def WithdrawDelegatorReward(self,
        request: global___MsgWithdrawDelegatorReward,
        context: grpc.ServicerContext,
    ) -> global___MsgWithdrawDelegatorRewardResponse: ...

    @abc.abstractmethod
    def WithdrawValidatorCommission(self,
        request: global___MsgWithdrawValidatorCommission,
        context: grpc.ServicerContext,
    ) -> global___MsgWithdrawValidatorCommissionResponse: ...

    @abc.abstractmethod
    def FundCommunityPool(self,
        request: global___MsgFundCommunityPool,
        context: grpc.ServicerContext,
    ) -> global___MsgFundCommunityPoolResponse: ...


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...
