"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    CurrentPlan:grpc.UnaryUnaryMultiCallable[
        global___QueryCurrentPlanRequest,
        global___QueryCurrentPlanResponse] = ...

    AppliedPlan:grpc.UnaryUnaryMultiCallable[
        global___QueryAppliedPlanRequest,
        global___QueryAppliedPlanResponse] = ...

    UpgradedConsensusState:grpc.UnaryUnaryMultiCallable[
        global___QueryUpgradedConsensusStateRequest,
        global___QueryUpgradedConsensusStateResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CurrentPlan(self,
        request: global___QueryCurrentPlanRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryCurrentPlanResponse: ...

    @abc.abstractmethod
    def AppliedPlan(self,
        request: global___QueryAppliedPlanRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryAppliedPlanResponse: ...

    @abc.abstractmethod
    def UpgradedConsensusState(self,
        request: global___QueryUpgradedConsensusStateRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryUpgradedConsensusStateResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
