"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .tx_pb2 import *
class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    SubmitProposal:grpc.UnaryUnaryMultiCallable[
        global___MsgSubmitProposal,
        global___MsgSubmitProposalResponse] = ...

    Vote:grpc.UnaryUnaryMultiCallable[
        global___MsgVote,
        global___MsgVoteResponse] = ...

    Deposit:grpc.UnaryUnaryMultiCallable[
        global___MsgDeposit,
        global___MsgDepositResponse] = ...


class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def SubmitProposal(self,
        request: global___MsgSubmitProposal,
        context: grpc.ServicerContext,
    ) -> global___MsgSubmitProposalResponse: ...

    @abc.abstractmethod
    def Vote(self,
        request: global___MsgVote,
        context: grpc.ServicerContext,
    ) -> global___MsgVoteResponse: ...

    @abc.abstractmethod
    def Deposit(self,
        request: global___MsgDeposit,
        context: grpc.ServicerContext,
    ) -> global___MsgDepositResponse: ...


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...
