"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import oracle.v1.oracle_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryCountsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryCountsRequest = QueryCountsRequest

class QueryCountsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_SOURCE_COUNT_FIELD_NUMBER: builtins.int
    ORACLE_SCRIPT_COUNT_FIELD_NUMBER: builtins.int
    REQUEST_COUNT_FIELD_NUMBER: builtins.int
    data_source_count: builtins.int = ...
    oracle_script_count: builtins.int = ...
    request_count: builtins.int = ...

    def __init__(self,
        *,
        data_source_count : builtins.int = ...,
        oracle_script_count : builtins.int = ...,
        request_count : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data_source_count",b"data_source_count",u"oracle_script_count",b"oracle_script_count",u"request_count",b"request_count"]) -> None: ...
global___QueryCountsResponse = QueryCountsResponse

class QueryDataRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_HASH_FIELD_NUMBER: builtins.int
    data_hash: typing.Text = ...

    def __init__(self,
        *,
        data_hash : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data_hash",b"data_hash"]) -> None: ...
global___QueryDataRequest = QueryDataRequest

class QueryDataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...

    def __init__(self,
        *,
        data : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data"]) -> None: ...
global___QueryDataResponse = QueryDataResponse

class QueryDataSourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
    data_source_id: builtins.int = ...

    def __init__(self,
        *,
        data_source_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data_source_id",b"data_source_id"]) -> None: ...
global___QueryDataSourceRequest = QueryDataSourceRequest

class QueryDataSourceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_SOURCE_FIELD_NUMBER: builtins.int

    @property
    def data_source(self) -> oracle.v1.oracle_pb2.DataSource: ...

    def __init__(self,
        *,
        data_source : typing.Optional[oracle.v1.oracle_pb2.DataSource] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data_source",b"data_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data_source",b"data_source"]) -> None: ...
global___QueryDataSourceResponse = QueryDataSourceResponse

class QueryOracleScriptRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ORACLE_SCRIPT_ID_FIELD_NUMBER: builtins.int
    oracle_script_id: builtins.int = ...

    def __init__(self,
        *,
        oracle_script_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"oracle_script_id",b"oracle_script_id"]) -> None: ...
global___QueryOracleScriptRequest = QueryOracleScriptRequest

class QueryOracleScriptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ORACLE_SCRIPT_FIELD_NUMBER: builtins.int

    @property
    def oracle_script(self) -> oracle.v1.oracle_pb2.OracleScript: ...

    def __init__(self,
        *,
        oracle_script : typing.Optional[oracle.v1.oracle_pb2.OracleScript] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"oracle_script",b"oracle_script"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"oracle_script",b"oracle_script"]) -> None: ...
global___QueryOracleScriptResponse = QueryOracleScriptResponse

class QueryRequestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.int = ...

    def __init__(self,
        *,
        request_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"request_id",b"request_id"]) -> None: ...
global___QueryRequestRequest = QueryRequestRequest

class QueryRequestResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_FIELD_NUMBER: builtins.int
    REPORTS_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int

    @property
    def request(self) -> oracle.v1.oracle_pb2.Request: ...

    @property
    def reports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[oracle.v1.oracle_pb2.Report]: ...

    @property
    def result(self) -> oracle.v1.oracle_pb2.Result: ...

    def __init__(self,
        *,
        request : typing.Optional[oracle.v1.oracle_pb2.Request] = ...,
        reports : typing.Optional[typing.Iterable[oracle.v1.oracle_pb2.Report]] = ...,
        result : typing.Optional[oracle.v1.oracle_pb2.Result] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"request",b"request",u"result",b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"reports",b"reports",u"request",b"request",u"result",b"result"]) -> None: ...
global___QueryRequestResponse = QueryRequestResponse

class QueryPendingRequestsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"validator_address",b"validator_address"]) -> None: ...
global___QueryPendingRequestsRequest = QueryPendingRequestsRequest

class QueryPendingRequestsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_IDS_FIELD_NUMBER: builtins.int

    @property
    def request_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...

    def __init__(self,
        *,
        request_ids : typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"request_ids",b"request_ids"]) -> None: ...
global___QueryPendingRequestsResponse = QueryPendingRequestsResponse

class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_FIELD_NUMBER: builtins.int

    @property
    def params(self) -> oracle.v1.oracle_pb2.Params: ...

    def __init__(self,
        *,
        params : typing.Optional[oracle.v1.oracle_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse

class QueryValidatorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"validator_address",b"validator_address"]) -> None: ...
global___QueryValidatorRequest = QueryValidatorRequest

class QueryValidatorResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATUS_FIELD_NUMBER: builtins.int

    @property
    def status(self) -> oracle.v1.oracle_pb2.ValidatorStatus: ...

    def __init__(self,
        *,
        status : typing.Optional[oracle.v1.oracle_pb2.ValidatorStatus] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"status",b"status"]) -> None: ...
global___QueryValidatorResponse = QueryValidatorResponse

class QueryReportersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"validator_address",b"validator_address"]) -> None: ...
global___QueryReportersRequest = QueryReportersRequest

class QueryReportersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REPORTER_FIELD_NUMBER: builtins.int

    @property
    def reporter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        reporter : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"reporter",b"reporter"]) -> None: ...
global___QueryReportersResponse = QueryReportersResponse

class QueryActiveValidatorsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryActiveValidatorsRequest = QueryActiveValidatorsRequest

class QueryActiveValidatorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATORS_FIELD_NUMBER: builtins.int

    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[oracle.v1.oracle_pb2.ActiveValidator]: ...

    def __init__(self,
        *,
        validators : typing.Optional[typing.Iterable[oracle.v1.oracle_pb2.ActiveValidator]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"validators",b"validators"]) -> None: ...
global___QueryActiveValidatorsResponse = QueryActiveValidatorsResponse

class QueryRequestSearchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ORACLE_SCRIPT_ID_FIELD_NUMBER: builtins.int
    CALLDATA_FIELD_NUMBER: builtins.int
    ASK_COUNT_FIELD_NUMBER: builtins.int
    MIN_COUNT_FIELD_NUMBER: builtins.int
    oracle_script_id: builtins.int = ...
    calldata: typing.Text = ...
    ask_count: builtins.int = ...
    min_count: builtins.int = ...

    def __init__(self,
        *,
        oracle_script_id : builtins.int = ...,
        calldata : typing.Text = ...,
        ask_count : builtins.int = ...,
        min_count : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"ask_count",b"ask_count",u"calldata",b"calldata",u"min_count",b"min_count",u"oracle_script_id",b"oracle_script_id"]) -> None: ...
global___QueryRequestSearchRequest = QueryRequestSearchRequest

class QueryRequestSearchResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_FIELD_NUMBER: builtins.int

    @property
    def request(self) -> global___QueryRequestResponse: ...

    def __init__(self,
        *,
        request : typing.Optional[global___QueryRequestResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"request",b"request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"request",b"request"]) -> None: ...
global___QueryRequestSearchResponse = QueryRequestSearchResponse

class QueryRequestPriceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SYMBOLS_FIELD_NUMBER: builtins.int
    ASK_COUNT_FIELD_NUMBER: builtins.int
    MIN_COUNT_FIELD_NUMBER: builtins.int

    @property
    def symbols(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    ask_count: builtins.int = ...
    min_count: builtins.int = ...

    def __init__(self,
        *,
        symbols : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ask_count : builtins.int = ...,
        min_count : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"ask_count",b"ask_count",u"min_count",b"min_count",u"symbols",b"symbols"]) -> None: ...
global___QueryRequestPriceRequest = QueryRequestPriceRequest

class QueryRequestPriceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRICE_RESULTS_FIELD_NUMBER: builtins.int

    @property
    def price_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[oracle.v1.oracle_pb2.PriceResult]: ...

    def __init__(self,
        *,
        price_results : typing.Optional[typing.Iterable[oracle.v1.oracle_pb2.PriceResult]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"price_results",b"price_results"]) -> None: ...
global___QueryRequestPriceResponse = QueryRequestPriceResponse

class QueryRequestVerificationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHAIN_ID_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    REPORTER_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    chain_id: typing.Text = ...
    validator: typing.Text = ...
    request_id: builtins.int = ...
    external_id: builtins.int = ...
    reporter: typing.Text = ...
    signature: builtins.bytes = ...

    def __init__(self,
        *,
        chain_id : typing.Text = ...,
        validator : typing.Text = ...,
        request_id : builtins.int = ...,
        external_id : builtins.int = ...,
        reporter : typing.Text = ...,
        signature : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"external_id",b"external_id",u"reporter",b"reporter",u"request_id",b"request_id",u"signature",b"signature",u"validator",b"validator"]) -> None: ...
global___QueryRequestVerificationRequest = QueryRequestVerificationRequest

class QueryRequestVerificationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHAIN_ID_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
    chain_id: typing.Text = ...
    validator: typing.Text = ...
    request_id: builtins.int = ...
    external_id: builtins.int = ...
    data_source_id: builtins.int = ...

    def __init__(self,
        *,
        chain_id : typing.Text = ...,
        validator : typing.Text = ...,
        request_id : builtins.int = ...,
        external_id : builtins.int = ...,
        data_source_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"data_source_id",b"data_source_id",u"external_id",b"external_id",u"request_id",b"request_id",u"validator",b"validator"]) -> None: ...
global___QueryRequestVerificationResponse = QueryRequestVerificationResponse

class QueryRequestPoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_KEY_FIELD_NUMBER: builtins.int
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    request_key: typing.Text = ...
    port_id: typing.Text = ...
    channel_id: typing.Text = ...

    def __init__(self,
        *,
        request_key : typing.Text = ...,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"port_id",b"port_id",u"request_key",b"request_key"]) -> None: ...
global___QueryRequestPoolRequest = QueryRequestPoolRequest

class QueryRequestPoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_POOL_ADDRESS_FIELD_NUMBER: builtins.int
    BALANCE_FIELD_NUMBER: builtins.int
    request_pool_address: typing.Text = ...

    @property
    def balance(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        request_pool_address : typing.Text = ...,
        balance : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"balance",b"balance",u"request_pool_address",b"request_pool_address"]) -> None: ...
global___QueryRequestPoolResponse = QueryRequestPoolResponse
