"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import ibc.core.channel.v1.genesis_pb2
import ibc.core.client.v1.genesis_pb2
import ibc.core.connection.v1.genesis_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_GENESIS_FIELD_NUMBER: builtins.int
    CONNECTION_GENESIS_FIELD_NUMBER: builtins.int
    CHANNEL_GENESIS_FIELD_NUMBER: builtins.int

    @property
    def client_genesis(self) -> ibc.core.client.v1.genesis_pb2.GenesisState: ...

    @property
    def connection_genesis(self) -> ibc.core.connection.v1.genesis_pb2.GenesisState: ...

    @property
    def channel_genesis(self) -> ibc.core.channel.v1.genesis_pb2.GenesisState: ...

    def __init__(self,
        *,
        client_genesis : typing.Optional[ibc.core.client.v1.genesis_pb2.GenesisState] = ...,
        connection_genesis : typing.Optional[ibc.core.connection.v1.genesis_pb2.GenesisState] = ...,
        channel_genesis : typing.Optional[ibc.core.channel.v1.genesis_pb2.GenesisState] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"channel_genesis",b"channel_genesis",u"client_genesis",b"client_genesis",u"connection_genesis",b"connection_genesis"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_genesis",b"channel_genesis",u"client_genesis",b"client_genesis",u"connection_genesis",b"connection_genesis"]) -> None: ...
global___GenesisState = GenesisState
